import { AxiosRequestConfig } from 'axios';
import { BaseRestClient, RestClientType } from './lib/BaseRestClient.js';
import { RestClientOptions } from './lib/requestUtils.js';
import { CreateStpGroupReq } from './types/request/account.js';
import { GetLoanCollateralRecordsReq, GetLoanOrdersReq, GetLoanRepaymentHistoryReq, SubmitLoanOrderReq, UpdateLoanCollateralReq } from './types/request/collateralLoan.js';
import { GetDeliveryAutoOrdersReq, GetDeliveryBookReq, GetDeliveryCandlesReq, GetDeliveryClosedPositionsReq, GetDeliveryLiquidationHistoryReq, GetDeliveryOrderBookReq, GetDeliveryOrdersReq, GetDeliverySettlementHistoryReq, GetDeliveryTradesReq, GetDeliveryTradingHistoryReq, SubmitDeliveryFuturesOrderReq } from './types/request/delivery.js';
import { GetStructuredProductListReq, GetStructuredProductOrdersReq } from './types/request/earn.js';
import { GetLendingInterestRecordsReq, GetLendingOrdersReq, GetLendingRecordsReq, SubmitLendOrRedeemReq } from './types/request/earnuni.js';
import { GetFlashSwapOrdersReq, SubmitFlashSwapOrderPreviewReq, SubmitFlashSwapOrderReq } from './types/request/flashswap.js';
import { BatchAmendOrderReq, DeleteAllFuturesOrdersReq, GetFundingRatesReq, GetFuturesAccountBookReq, GetFuturesAutoOrdersReq, GetFuturesCandlesReq, GetFuturesLiquidationHistoryReq, GetFuturesOrderBookReq, GetFuturesOrdersByTimeRangeReq, GetFuturesOrdersReq, GetFuturesPositionHistoryReq, GetFuturesPositionsReq, GetFuturesStatsReq, GetFuturesTradesReq, GetFuturesTradingHistoryByTimeRangeReq, GetFuturesTradingHistoryReq, GetLiquidationHistoryReq, GetRiskLimitTiersReq, SubmitFuturesOrderReq, SubmitFuturesTriggeredOrderReq, UpdateDualModePositionLeverageReq, UpdateDualModePositionMarginReq, UpdateFuturesOrderReq } from './types/request/futures.js';
import { GetCrossMarginAccountHistoryReq, GetCrossMarginBorrowHistoryReq, GetCrossMarginInterestRecordsReq, GetCrossMarginRepaymentsReq, GetMarginBalanceHistoryReq, SubmitCrossMarginBorrowLoanReq } from './types/request/margin.js';
import { GetMarginUNIInterestRecordsReq, GetMarginUNILoanRecordsReq, GetMarginUNILoansReq, GetMarginUNIMaxBorrowReq } from './types/request/marginuni.js';
import { GetMultiLoanAdjustmentRecordsReq, GetMultiLoanOrdersReq, GetMultiLoanRepayRecordsReq, RepayMultiLoanReq, SubmitMultiLoanOrderReq, UpdateMultiLoanReq } from './types/request/multicollateralLoan.js';
import { GetOptionsAccountChangeReq, GetOptionsCandlesReq, GetOptionsMySettlementsReq, GetOptionsOrderBookReq, GetOptionsOrdersReq, GetOptionsPersonalHistoryReq, GetOptionsSettlementHistoryReq, GetOptionsTradesReq, GetOptionsUnderlyingCandlesReq, OptionsMMPSettingsReq, SubmitOptionsOrderReq } from './types/request/options.js';
import { GetAgencyCommissionHistoryReq, GetAgencyTransactionHistoryReq, GetBrokerCommissionHistoryReq, GetBrokerTransactionHistoryReq, GetPartnerSubordinateListReq, PartnerTransactionReq } from './types/request/rebate.js';
import { CancelSpotBatchOrdersReq, DeleteSpotOrderReq, GetSpotAccountBookReq, GetSpotAutoOrdersReq, GetSpotCandlesReq, GetSpotInsuranceHistoryReq, GetSpotOrderBookReq, GetSpotOrderReq, GetSpotOrdersReq, GetSpotTradesReq, GetSpotTradingHistoryReq, SubmitSpotClosePosCrossDisabledReq, SubmitSpotOrderReq, UpdateSpotBatchOrdersReq, UpdateSpotOrderReq } from './types/request/spot.js';
import { CreateSubAccountApiKeyReq, CreateSubAccountReq, UpdateSubAccountApiKeyReq } from './types/request/subaccount.js';
import { GetUnifiedHistoryLendingRateReq, GetUnifiedInterestRecordsReq, GetUnifiedLoanRecordsReq, GetUnifiedLoansReq, PortfolioMarginCalculatorReq, SetUnifiedAccountModeReq, SubmitUnifiedBorrowOrRepayReq } from './types/request/unified.js';
import { GetMainSubTransfersReq, GetSavedAddressReq, GetSmallBalanceHistoryReq, GetWithdrawalDepositRecordsReq, ListPushOrdersReq, SubmitMainSubTransferReq, SubmitSubToSubTransferReq, SubmitTransferReq } from './types/request/wallet.js';
import { SubmitWithdrawalReq } from './types/request/withdrawal.js';
import { AccountDetail, AccountRateLimit, StpGroup, StpGroupUser } from './types/response/account.js';
import { LoanCollateralRatio, LoanCollateralRecord, LoanOrder, LoanRepaymentHistoryRecord } from './types/response/collateralloan.js';
import { DeliveryAccount, DeliveryBook, DeliveryCandle, DeliveryClosedPosition, DeliveryLiquidationHistoryRecord, DeliveryOrderBook, DeliverySettlementHistoryRecord, DeliveryTicker, DeliveryTrade, DeliveryTradingHistoryRecord } from './types/response/delivery.js';
import { DualInvestmentOrder, DualInvestmentProduct, StructuredProduct, StructuredProductOrder } from './types/response/earn.js';
import { LendingCurrency, LendingInterestRecord, LendingOrder, LendingRecord } from './types/response/earnuni.js';
import { FlashSwapCurrencyPair, FlashSwapOrder, SubmitFlashSwapOrderPreviewResp } from './types/response/flashswap.js';
import { BatchAmendOrderResp, DeleteFuturesBatchOrdersResp, FuturesAccount, FuturesAccountBookRecord, FuturesAutoDeleveragingHistoryRecord, FuturesCandle, FuturesContract, FuturesDeliveryContract, FuturesLiquidationHistoryRecord, FuturesOrder, FuturesOrderBook, FuturesPosition, FuturesPositionHistoryRecord, FuturesPriceTriggeredOrder, FuturesStats, FuturesTicker, FuturesTrade, FuturesTradingHistoryRecord, IndexConstituents, LiquidationHistoryRecord, PremiumIndexKLine, RiskLimitTier } from './types/response/futures.js';
import { CrossMarginAccount, CrossMarginAccountHistoryRecord, CrossMarginCurrency, CrossMarginMorrowLoanRecord, MarginAccount, MarginBalanceHistoryRecord } from './types/response/margin.js';
import { LendingMarket, MarginUNIInterestRecord, MarginUNILoan, MarginUNILoanRecord, MarginUNIMaxBorrowable } from './types/response/marginuni.js';
import { MultiLoanAdjustmentRecord, MultiLoanCurrencyQuota, MultiLoanFixedRate, MultiLoanOrder, MultiLoanRatio, MultiLoanRepayRecord, MultiLoanSupportedCurrencies, RepayMultiLoanResp, UpdateMultiLoanResp } from './types/response/multicollateralLoan.js';
import { GetOptionsLiquidationResp, OptionsAccount, OptionsAccountChangeRecord, OptionsCandle, OptionsContract, OptionsMMPSettings, OptionsOrderBook, OptionsPositionsUnderlying, OptionsSettlementHistoryRecord, OptionsTicker, OptionsTrade, OptionsUnderlyingCandle, OptionsUserHistoryRecord, OptionsUserSettlement, SubmitOptionsOrderResp } from './types/response/options.js';
import { AgencyCommissionHistoryRecord, AgencyTransactionHistoryRecord, BrokerCommissionHistoryRecord, BrokerTransactionHistoryRecord, PartnerCommission, PartnerSubordinate, PartnerTransaction } from './types/response/rebate.js';
import { DeleteSpotBatchOrdersResp, GetSpotOpenOrdersResp, SpotAccount, SpotAccountBook, SpotCandle, SpotCurrency, SpotFeeRates, SpotHistoricTradeRecord, SpotInsuranceHistory, SpotOrder, SpotOrderBook, SpotPriceTriggeredOrder, SpotTicker, SpotTrade, SubmitSpotBatchOrdersResp } from './types/response/spot.js';
import { CreatedSubAccountAPIKey, SubAccount, SubAccountAPIKey, SubAccountMode } from './types/response/subaccount.js';
import { MarginTier, PortfolioMarginCalculation, UnifiedAccountInfo, UnifiedCurrencyDiscountTiers, UnifiedHistoryLendingRate, UnifiedInterestRecord, UnifiedLoan, UnifiedLoanRecord, UnifiedRiskUnitDetails, UserCurrencyLeverageConfig } from './types/response/unified.js';
import { CreateDepositAddressResp, CurrencyChain, GetBalancesResp, PushOrder, SavedAddress, SmallBalanceHistoryRecord, SmallBalanceRecord, SubAccountCrossMarginBalancesResp, SubAccountFuturesBalancesResp, SubAccountMarginBalance, SubAccountTransferRecord, TradingFees, WithdrawalStatus } from './types/response/wallet.js';
import { WithdrawalRecord } from './types/response/withdrawal.js';
import { CurrencyPair } from './types/shared.js';
/**
 * Unified REST API client for all of Gate's REST APIs
 */
export declare class RestClient extends BaseRestClient {
    constructor(restClientOptions?: RestClientOptions, requestOptions?: AxiosRequestConfig);
    /**
     *
     * Custom SDK functions
     *
     */
    /**
     * This method is used to get the latency and time sync between the client and the server.
     * This is not official API endpoint and is only used for internal testing purposes.
     * Use this method to check the latency and time sync between the client and the server.
     * Final values might vary slightly, but it should be within few ms difference.
     * If you have any suggestions or improvements to this measurement, please create an issue or pull request on GitHub.
     */
    fetchLatencySummary(): Promise<any>;
    /**
     *
     * Gate.io misc endpoints
     *
     */
    getClientType(): RestClientType;
    getSystemMaintenanceStatus(): Promise<any>;
    /**================================================================================================================================
     * WITHDRAW
     * ==========================================================================================================================
     */
    /**
     * Withdraw
     *
     * Withdrawals to Gate addresses do not incur transaction fees.
     *
     * @param params Withdrawal parameters
     * @returns Promise<Withdraw>
     */
    submitWithdrawal(params: SubmitWithdrawalReq): Promise<WithdrawalRecord>;
    /**
     * Transfer between spot main accounts
     *
     * Both parties cannot be sub-accounts.
     *
     * @param params Transfer parameters
     * @returns Promise<{
     *   id: number;
     * }>
     */
    submitSpotMainAccountTransfer(params: {
        receive_uid: number;
        currency: string;
        amount: string;
    }): Promise<{
        id: number;
    }>;
    /**
     * Cancel withdrawal with specified ID
     *
     * @param params Parameters containing the withdrawal ID
     * @returns Promise<Withdraw>
     */
    cancelWithdrawal(params: {
        withdrawal_id: string;
    }): Promise<WithdrawalRecord>;
    /**==========================================================================================================================
     * WALLET
     * ==========================================================================================================================
     */
    /**
     * List chains supported for specified currency
     *
     * @param params Parameters containing the currency name
     * @returns Promise< GetCurrencyChainsResp[][]>
     */
    getCurrencyChains(params: {
        currency: string;
    }): Promise<CurrencyChain[]>;
    /**
     * Generate currency deposit address
     *
     * @param params Parameters containing the currency name
     * @returns Promise<CreateDepositAddressResp>
     */
    createDepositAddress(params: {
        currency: string;
    }): Promise<CreateDepositAddressResp>;
    /**
     * Retrieve withdrawal records
     *
     * Record time range cannot exceed 30 days
     *
     * @param params Parameters for filtering withdrawal records
     * @returns Promise<Withdraw[]>
     */
    getWithdrawalRecords(params?: GetWithdrawalDepositRecordsReq): Promise<WithdrawalRecord[]>;
    /**
     * Retrieve deposit records
     *
     * Record time range cannot exceed 30 days
     *
     * @param params Parameters for filtering deposit records
     * @returns Promise<Withdraw[]>
     */
    getDepositRecords(params?: GetWithdrawalDepositRecordsReq): Promise<WithdrawalRecord[]>;
    /**
     * Transfer between trading accounts
     *
     * Transfer between different accounts. Currently support transfers between the following:
     * - spot - margin
     * - spot - futures(perpetual)
     * - spot - delivery
     * - spot - cross margin
     * - spot - options
     *
     * @param params Transfer parameters
     * @returns Promise<TransferResponse>
     */
    submitTransfer(params: SubmitTransferReq): Promise<{
        tx_id: number;
    }>;
    /**
     * Transfer between main and sub accounts
     *
     * Support transferring with sub user's spot or futures account. Note that only main user's spot account is used no matter which sub user's account is operated.
     *
     * @param params Transfer parameters
     * @returns Promise<any>
     */
    submitMainSubTransfer(params: SubmitMainSubTransferReq): Promise<any>;
    /**
     * Retrieve transfer records between main and sub accounts
     *
     * Record time range cannot exceed 30 days
     *
     * Note: only records after 2020-04-10 can be retrieved
     *
     * @param params Parameters for filtering transfer records
     * @returns Promise<SubAccountTransferRecordResp[]>
     */
    getMainSubTransfers(params?: GetMainSubTransfersReq): Promise<SubAccountTransferRecord[]>;
    /**
     * Sub-account transfers to sub-account
     *
     * It is possible to perform balance transfers between two sub-accounts under the same main account. You can use either the API Key of the main account or the API Key of the sub-account to initiate the transfer.
     *
     * @param params Transfer parameters
     * @returns Promise<any>
     */
    submitSubToSubTransfer(params: SubmitSubToSubTransferReq): Promise<any>;
    /**
     * Query transfer status based on client_order_id or tx_id
     *
     * @param params Parameters for querying transfer status
     * @returns Promise<{
     *   tx_id: string;
     *   status: 'PENDING' | 'SUCCESS' | 'FAIL' | 'PARTIAL_SUCCESS';
     * }>
     */
    getTransferStatus(params: {
        client_order_id?: string;
        tx_id?: string;
    }): Promise<{
        tx_id: string;
        status: 'PENDING' | 'SUCCESS' | 'FAIL' | 'PARTIAL_SUCCESS';
    }>;
    /**
     * Retrieve withdrawal status
     *
     * @param params Parameters for retrieving withdrawal status
     * @returns Promise<GetWithdrawalStatusResp[]>
     */
    getWithdrawalStatus(params?: {
        currency?: string;
    }): Promise<WithdrawalStatus[]>;
    /**
     * Retrieve sub account balances
     *
     * @param params Parameters for retrieving sub account balances
     * @returns Promise<{
          uid: string;
          available: { [key: string]: string };
        }[]>
     */
    getSubBalance(params?: {
        sub_uid?: string;
    }): Promise<{
        uid: string;
        available: {
            [key: string]: string;
        };
    }[]>;
    /**
     * Query sub accounts' margin balances
     *
     * @param params Parameters for querying sub accounts' margin balances
     * @returns Promise<SubAccountMarginBalancesResp[]>
     */
    getSubMarginBalances(params?: {
        sub_uid?: string;
    }): Promise<{
        uid: string;
        available: SubAccountMarginBalance[];
    }>;
    /**
     * Query sub accounts' futures account balances
     *
     * @param params Parameters for querying sub accounts' futures account balances
     * @returns Promise<SubAccountFuturesBalancesResp[]>
     */
    getSubFuturesBalances(params?: {
        sub_uid?: string;
        settle?: string;
    }): Promise<SubAccountFuturesBalancesResp[]>;
    /**
     * Query subaccount's cross_margin account info
     *
     * @param params Parameters for querying subaccount's cross_margin account info
     * @returns Promise<SubAccountCrossMarginBalancesResp[]>
     */
    getSubCrossMarginBalances(params?: {
        sub_uid?: string;
    }): Promise<SubAccountCrossMarginBalancesResp[]>;
    /**
     * Query saved addresses
     *
     * @param params Parameters for querying saved address
     * @returns Promise<GetSavedAddressResp[]>
     */
    getSavedAddresses(params: GetSavedAddressReq): Promise<SavedAddress[]>;
    /**
     * Retrieve personal trading fee
     *
     * @param params Parameters for retrieving personal trading fee
     * @returns Promise<GetTradingFeesResp>
     */
    getTradingFees(params?: {
        currency_pair?: string;
        settle?: 'BTC' | 'USDT' | 'USD';
    }): Promise<TradingFees>;
    /**
     * Retrieve user's total balances
     *
     * This endpoint returns an approximate sum of exchanged amount from all currencies to input currency for each account.
     * The exchange rate and account balance could have been cached for at most 1 minute. It is not recommended to use its result for any trading calculation.
     *
     * For trading calculation, use the corresponding account query endpoint for each account type. For example:
     * - GET /spot/accounts to query spot account balance
     * - GET /margin/accounts to query margin account balance
     * - GET /futures/{settle}/accounts to query futures account balance
     *
     * @param params Parameters for retrieving total balances
     * @returns Promise<GetBalancesResp>
     */
    getBalances(params?: {
        currency?: string;
    }): Promise<GetBalancesResp>;
    /**
     * List small balance
     *
     * @returns Promise<GetSmallBalancesResp>
     */
    getSmallBalances(): Promise<SmallBalanceRecord>;
    /**
     * Convert small balance
     *
     * @param params Parameters for converting small balance
     * @returns Promise<any>
     */
    convertSmallBalance(params?: {
        currency?: string[];
        is_all?: boolean;
    }): Promise<any>;
    /**
     * List small balance history
     *
     * @param params Parameters for listing small balance history
     * @returns Promise<GetSmallBalanceHistoryResp[]>
     */
    getSmallBalanceHistory(params?: GetSmallBalanceHistoryReq): Promise<SmallBalanceHistoryRecord[]>;
    /**
     * List push orders
     *
     * @param params Parameters for listing push orders
     * @returns Promise<PushOrder[]>
     */
    getPushOrders(params?: ListPushOrdersReq): Promise<PushOrder[]>;
    /**==========================================================================================================================
     * SUBACCOUNT
     * ==========================================================================================================================
     */
    /**
     * Create a new sub-account
     *
     * @param params Parameters for creating a new sub-account
     * @returns Promise<CreateSubAccountResp>
     */
    createSubAccount(params: CreateSubAccountReq): Promise<SubAccount>;
    /**
     * List sub-accounts
     *
     * @param params Parameters for listing sub-accounts
     * @returns Promise<GetSubAccountsResp[]>
     */
    getSubAccounts(params?: {
        type?: string;
    }): Promise<SubAccount[]>;
    /**
     * Get the sub-account
     *
     * @param params Parameters containing the sub-account user ID
     * @returns Promise<SubAccountResp>
     */
    getSubAccount(params: {
        user_id: number;
    }): Promise<SubAccount>;
    /**
     * Create API Key of the sub-account
     *
     * @param params Parameters for creating API Key of the sub-account
     * @returns Promise<CreateSubAccountApiKeyResp>
     */
    createSubAccountApiKey(params: CreateSubAccountApiKeyReq): Promise<CreatedSubAccountAPIKey>;
    /**
     * List all API Key of the sub-account
     *
     * @param params Parameters containing the sub-account user ID
     * @returns Promise<SubAccountKey[]>
     */
    getSubAccountApiKeys(params: {
        user_id: number;
    }): Promise<SubAccountAPIKey[]>;
    /**
     * Update API key of the sub-account
     *
     * @param params Parameters for updating API key of the sub-account
     * @returns Promise<any>
     */
    updateSubAccountApiKey(params: UpdateSubAccountApiKeyReq): Promise<any>;
    /**
     * Delete API key of the sub-account
     *
     * @param params Parameters for deleting API key of the sub-account
     * @returns Promise<any>
     */
    deleteSubAccountApiKey(params: {
        user_id: number;
        key: string;
    }): Promise<any>;
    /**
     * Get the API Key of the sub-account
     *
     * @param params Parameters containing the sub-account user ID and API key
     * @returns Promise<SubAccountKey>
     */
    getSubAccountApiKey(params: {
        user_id: number;
        key: string;
    }): Promise<SubAccountAPIKey>;
    /**
     * Lock the sub-account
     *
     * @param params Parameters containing the sub-account user ID
     * @returns Promise<any>
     */
    lockSubAccount(params: {
        user_id: number;
    }): Promise<any>;
    /**
     * Unlock the sub-account
     *
     * @param params Parameters containing the sub-account user ID
     * @returns Promise<any>
     */
    unlockSubAccount(params: {
        user_id: number;
    }): Promise<any>;
    /**
     * Get sub-account mode
     *
     * Unified account mode:
     * - classic: Classic account mode
     * - multi_currency: Multi-currency margin mode
     * - portfolio: Portfolio margin mode
     *
     * @returns Promise<SubAccountMode>
     */
    getSubAccountMode(): Promise<SubAccountMode>;
    /**==========================================================================================================================
     * UNIFIED
     * ==========================================================================================================================
     */
    /**
     * Get unified account information
     *
     * The assets of each currency in the account will be adjusted according to their liquidity, defined by corresponding adjustment coefficients, and then uniformly converted to USD to calculate the total asset value and position value of the account.
     *
     * @param params Parameters for retrieving unified account information
     * @returns Promise<GetUnifiedAccountInfoResp>
     */
    getUnifiedAccountInfo(params?: {
        currency?: string;
        sub_uid?: string;
    }): Promise<UnifiedAccountInfo>;
    /**
     * Query about the maximum borrowing for the unified account
     *
     * @param params Parameters for querying the maximum borrowing for the unified account
     * @returns Promise<{
     *   currency: string;
     *   amount: string;
     * }>
     */
    getUnifiedMaxBorrow(params: {
        currency: string;
    }): Promise<{
        currency: string;
        amount: string;
    }>;
    /**
     * Query about the maximum transferable for the unified account
     *
     * @param params Parameters for querying the maximum transferable for the unified account
     * @returns Promise<{
     *   currency: string;
     *   amount: string;
     * }>
     */
    getUnifiedMaxTransferable(params: {
        currency: string;
    }): Promise<{
        currency: string;
        amount: string;
    }>;
    /**
     * Borrow or repay
     *
     * When borrowing, it is essential to ensure that the borrowed amount is not below the minimum borrowing threshold for the specific cryptocurrency and does not exceed the maximum borrowing limit set by the platform and the user.
     *
     * The interest on the loan will be automatically deducted from the account at regular intervals. It is the user's responsibility to manage the repayment of the borrowed amount.
     *
     * For repayment, the option to repay the entire borrowed amount is available by setting the parameter repaid_all=true
     *
     * @param params Parameters for borrowing or repaying
     * @returns Promise<any>
     */
    submitUnifiedBorrowOrRepay(params: SubmitUnifiedBorrowOrRepayReq): Promise<any>;
    /**
     * List loans
     *
     * @param params Parameters for listing loans
     * @returns Promise<GetUnifiedLoansResp[]>
     */
    getUnifiedLoans(params?: GetUnifiedLoansReq): Promise<UnifiedLoan[]>;
    /**
     * Get loan records
     *
     * @param params Parameters for getting loan records
     * @returns Promise<GetUnifiedLoanRecordsResp[]>
     */
    getUnifiedLoanRecords(params?: GetUnifiedLoanRecordsReq): Promise<UnifiedLoanRecord[]>;
    /**
     * List interest records
     *
     * @param params Parameters for listing interest records
     * @returns Promise<GetUnifiedInterestRecordsResp[]>
     */
    getUnifiedInterestRecords(params?: GetUnifiedInterestRecordsReq): Promise<UnifiedInterestRecord[]>;
    /**
     * Retrieve user risk unit details, only valid in portfolio margin mode
     *
     * @returns Promise<GetUnifiedRiskUnitDetailsResp>
     */
    getUnifiedRiskUnitDetails(): Promise<UnifiedRiskUnitDetails>;
    /**
     * Set mode of the unified account
     *
     * Switching between different account modes requires only passing the parameters corresponding to the target account mode. It also supports opening or closing configuration switches for the corresponding account mode when switching.
     *
     * @param params Parameters for setting the mode of the unified account
     * @returns Promise<any>
     */
    setUnifiedAccountMode(params: SetUnifiedAccountModeReq): Promise<any>;
    /**
     * Query mode of the unified account
     *
     * @returns Promise<SetUnifiedAccountModeReq>
     */
    getUnifiedAccountMode(): Promise<SetUnifiedAccountModeReq>;
    /**
     * Get unified estimate rate
     *
     * Due to fluctuations in lending depth, hourly interest rates may vary, and thus, I cannot provide exact rates. When a currency is not supported, the interest rate returned will be an empty string.
     *
     * @param params Parameters for querying estimate rates
     * @returns Promise<{ [key: string]: string }>
     */
    getUnifiedEstimateRate(params: {
        currencies: string[];
    }): Promise<{
        [key: string]: string;
    }>;
    /**
     * List currency discount tiers
     *
     * @returns Promise<GetUnifiedCurrencyDiscountTiersResp[]>
     */
    getUnifiedCurrencyDiscountTiers(): Promise<UnifiedCurrencyDiscountTiers[]>;
    /**
     * List loan margin tiers
     *
     * @returns Promise<{
     *   currency: string;
     *   margin_tiers: MarginTier[];
     * }[]>
     */
    getLoanMarginTiers(): Promise<{
        currency: string;
        margin_tiers: MarginTier[];
    }[]>;
    /**
     * Portfolio margin calculator
     *
     * Portfolio Margin Calculator When inputting a simulated position portfolio, each position includes the position name and quantity held, supporting markets within the range of BTC and ETH perpetual contracts, options, and spot markets. When inputting simulated orders, each order includes the market identifier, order price, and order quantity, supporting markets within the range of BTC and ETH perpetual contracts, options, and spot markets. Market orders are not included.
     *
     * @param params Parameters for portfolio margin calculator
     * @returns Promise<PortfolioMarginCalculatorResp>
     */
    portfolioMarginCalculate(params: PortfolioMarginCalculatorReq): Promise<PortfolioMarginCalculation>;
    /**
     * Query user currency leverage configuration
     *
     * Get the maximum and minimum leverage multiples that users can set for a currency type
     *
     * @param params Parameters containing the currency
     * @returns Promise<UserCurrencyLeverageConfig>
     */
    getUserCurrencyLeverageConfig(params: {
        currency: string;
    }): Promise<UserCurrencyLeverageConfig>;
    /**
     * Get the user's currency leverage
     *
     * If currency is not passed, query all currencies.
     *
     * @param params Optional parameters containing the currency
     * @returns Promise<UserCurrencyLeverageSetting[]>
     */
    getUserCurrencyLeverageSettings(params?: {
        currency?: string;
    }): Promise<{
        currency: string;
        leverage: string;
    }[]>;
    /**
     * Set the currency leverage ratio
     *
     * @param params Parameters for setting currency leverage ratio
     * @returns Promise<any> Returns nothing on success (204 No Content)
     */
    updateUserCurrencyLeverage(params: {
        currency: string;
        leverage: string;
    }): Promise<any>;
    /**
     * Get historical lending rates
     *
     * @param params Parameters for retrieving historical lending rates
     * @returns Promise<UnifiedHistoryLendingRate>
     */
    getHistoricalLendingRates(params: GetUnifiedHistoryLendingRateReq): Promise<UnifiedHistoryLendingRate>;
    /**==========================================================================================================================
     * SPOT
     * ==========================================================================================================================
     */
    /**
     * List all currencies' details
     *
     * Currency has two forms:
     * - Only currency name, e.g., BTC, USDT
     * - <currency>_<chain>, e.g., HT_ETH
     *
     * The latter one occurs when one currency has multiple chains. Currency detail contains a chain field whatever the form is. To retrieve all chains of one currency, you can use all the details which have the name of the currency or name starting with <currency>_.
     *
     * @returns Promise<GetSpotCurrenciesResp[]>
     */
    getSpotCurrencies(): Promise<SpotCurrency[]>;
    /**
     * Get details of a specific currency
     *
     * @param params Parameters for retrieving details of a specific currency
     * @returns Promise<GetSpotCurrenciesResp>
     */
    getSpotCurrency(params: {
        currency: string;
    }): Promise<SpotCurrency>;
    /**
     * List all currency pairs supported
     *
     * @returns Promise<CurrencyPair[]>
     */
    getSpotCurrencyPairs(): Promise<CurrencyPair[]>;
    /**
     * Get details of a specific currency pair
     *
     * @param params Parameters for retrieving details of a specific currency pair
     * @returns Promise<CurrencyPair>
     */
    getSpotCurrencyPair(params: {
        currency_pair: string;
    }): Promise<CurrencyPair>;
    /**
     * Retrieve ticker information
     *
     * Return only related data if currency_pair is specified; otherwise return all of them.
     *
     * @param params Parameters for retrieving ticker information
     * @returns Promise<GetSpotTickerResp[]>
     */
    getSpotTicker(params?: {
        currency_pair?: string;
        timezone?: 'utc0' | 'utc8' | 'all';
    }): Promise<SpotTicker[]>;
    /**
     * Retrieve order book
     *
     * Order book will be sorted by price from high to low on bids; low to high on asks.
     *
     * @param params Parameters for retrieving order book
     * @returns Promise<GetSpotOrderBookResp>
     */
    getSpotOrderBook(params: GetSpotOrderBookReq): Promise<SpotOrderBook>;
    /**
     * Retrieve market trades
     *
     * You can use from and to to query by time range, or use last_id by scrolling page. The default behavior is by time range.
     * Scrolling query using last_id is not recommended any more. If last_id is specified, time range query parameters will be ignored.
     *
     * @param params Parameters for retrieving market trades
     * @returns Promise<GetSpotTradesResp[]>
     */
    getSpotTrades(params: GetSpotTradesReq): Promise<SpotTrade[]>;
    /**
     * Market Candles
     *
     * Maximum of 1000 points can be returned in a query. Be sure not to exceed the limit when specifying from, to and interval.
     *
     * @param params Parameters for retrieving market Candles
     * @returns Promise<GetSpotCandlesResp>
     */
    getSpotCandles(params: GetSpotCandlesReq): Promise<SpotCandle[]>;
    /**
     * Query user trading fee rates
     *
     * This API is deprecated in favour of new fee retrieving API /wallet/fee.
     *
     * @param params Parameters for querying user trading fee rates
     * @returns Promise<GetSpotFeeRatesResp>
     */
    getSpotFeeRates(params?: {
        currency_pair?: string;
    }): Promise<SpotFeeRates>;
    /**
     * Query a batch of user trading fee rates
     *
     * @param params Parameters for querying a batch of user trading fee rates
     */
    getSpotBatchFeeRates(params: {
        currency_pairs: string;
    }): Promise<Record<string, SpotFeeRates>>;
    /**
     * List spot accounts
     *
     * @param params Parameters for listing spot accounts
     * @returns Promise<GetSpotAccountsResp[]>
     */
    getSpotAccounts(params?: {
        currency?: string;
    }): Promise<SpotAccount[]>;
    /**
     * Query account book
     *
     * Record time range cannot exceed 30 days.
     *
     * @param params Parameters for querying account book
     * @returns Promise<GetSpotAccountBookResp[]>
     */
    getSpotAccountBook(params?: GetSpotAccountBookReq): Promise<SpotAccountBook[]>;
    /**
     * Create a batch of orders
     *
     * Batch orders requirements:
     * - custom order field text is required
     * - At most 4 currency pairs, maximum 10 orders each, are allowed in one request
     * - No mixture of spot orders and margin orders, i.e. account must be identical for all orders
     *
     * NOTE: The "xGateExptime" parameter will translate to the "x-gate-exptime" header.
     *
     * @param params Parameters for creating a batch of orders
     * @returns Promise<SubmitSpotBatchOrdersResp[]>
     */
    submitSpotBatchOrders(body: SpotOrder[], params?: {
        xGateExptime?: number;
    }): Promise<SubmitSpotBatchOrdersResp[]>;
    /**
     * List all open orders
     *
     * List open orders in all currency pairs.
     * Note that pagination parameters affect record number in each currency pair's open order list. No pagination is applied to the number of currency pairs returned. All currency pairs with open orders will be returned.
     * Spot, portfolio, and margin orders are returned by default. To list cross margin orders, account must be set to cross_margin.
     *
     * @param params Parameters for listing all open orders
     * @returns Promise<GetSpotOpenOrdersResp[]>
     */
    getSpotOpenOrders(params?: {
        page?: number;
        limit?: number;
        account?: 'spot' | 'margin' | 'cross_margin' | 'unified';
    }): Promise<GetSpotOpenOrdersResp[]>;
    /**
     * Close position when cross-currency is disabled
     *
     * Currently, only cross-margin accounts are supported to close position when cross currencies are disabled. Maximum buy quantity = (unpaid principal and interest - currency balance - the amount of the currency in the order book) / 0.998
     *
     * @param params Parameters for closing position when cross-currency is disabled
     * @returns Promise<Order>
     */
    submitSpotClosePosCrossDisabled(params: SubmitSpotClosePosCrossDisabledReq): Promise<SpotOrder>;
    /**
     * Create an order
     *
     * You can place orders with spot, portfolio, margin or cross margin account through setting the account field. It defaults to spot, which means spot account is used to place orders. If the user is using unified account, it defaults to the unified account.
     *
     * NOTE: The "xGateExptime" parameter will translate to the "x-gate-exptime" header.
     *
     * @param params Parameters for creating an order
     * @returns Promise<Order>
     */
    submitSpotOrder(params: SubmitSpotOrderReq): Promise<SpotOrder>;
    /**
     * List orders
     *
     * Spot, portfolio and margin orders are returned by default. If cross margin orders are needed, account must be set to cross_margin.
     *
     * @param params Parameters for listing orders
     * @returns Promise<Order[]>
     */
    getSpotOrders(params: GetSpotOrdersReq): Promise<SpotOrder[]>;
    /**
     * Cancel all open orders in specified currency pair
     *
     * If account is not set, all open orders, including spot, portfolio, margin and cross margin ones, will be cancelled.
     * You can set account to cancel only orders within the specified account.
     *
     * NOTE: The "xGateExptime" parameter will translate to the "x-gate-exptime" header.
     *
     * @param params Parameters for cancelling all open orders in specified currency pair
     * @returns Promise<Order[]>
     */
    cancelSpotOpenOrders(params: {
        currency_pair: string;
        side?: 'buy' | 'sell';
        account?: 'spot' | 'margin' | 'cross_margin' | 'unified';
        action_mode?: 'ACK' | 'RESULT' | 'FULL';
        xGateExptime?: number;
    }): Promise<SpotOrder[]>;
    /**
     * Cancel a batch of orders with an ID list
     *
     * Multiple currency pairs can be specified, but maximum 20 orders are allowed per request.
     *
     * NOTE: The "xGateExptime" parameter will translate to the "x-gate-exptime" header.
     *
     * @param params Parameters for cancelling a batch of orders
     * @returns Promise<DeleteSpotBatchOrdersResp[]>
     */
    batchCancelSpotOrders(body: CancelSpotBatchOrdersReq[], params?: {
        xGateExptime?: number;
    }): Promise<DeleteSpotBatchOrdersResp[]>;
    /**
     * Get a single order
     *
     * Spot, portfolio and margin orders are queried by default. If cross margin orders are needed or portfolio margin account are used, account must be set to cross_margin.
     *
     * @param params Parameters for getting a single order
     * @returns Promise<Order>
     */
    getSpotOrder(params: GetSpotOrderReq): Promise<SpotOrder>;
    /**
     * Amend an order
     *
     * By default, the orders of spot, portfolio and margin account are updated. If you need to modify orders of the cross-margin account, you must specify account as cross_margin. For portfolio margin account, only cross_margin account is supported.
     *
     * Currently, only supports modification of price or amount fields.
     *
     * NOTE: The "xGateExptime" parameter will translate to the "x-gate-exptime" header.
     *
     * @param params Parameters for amending an order
     * @returns Promise<Order>
     */
    updateSpotOrder(params: UpdateSpotOrderReq): Promise<SpotOrder>;
    /**
     * Cancel a single order
     *
     * Spot, portfolio and margin orders are cancelled by default. If trying to cancel cross margin orders or portfolio margin account are used, account must be set to cross_margin.
     *
     * NOTE: The "xGateExptime" parameter will translate to the "x-gate-exptime" header.
     *
     * @param params Parameters for cancelling a single order
     * @returns Promise<Order>
     */
    cancelSpotOrder(params: DeleteSpotOrderReq): Promise<SpotOrder>;
    /**
     * List personal trading history
     *
     * Spot, portfolio and margin trades are queried by default. If cross margin trades are needed, account must be set to cross_margin.
     *
     * You can also set from and/or to to query by time range. If you don't specify from and/or to parameters, only the last 7 days of data will be returned. The range of from and to is not allowed to exceed 30 days. Time range parameters are handled as order finish time.
     *
     * @param params Parameters for listing personal trading history
     * @returns Promise<GetSpotTradingHistoryResp[]>
     */
    getSpotTradingHistory(params?: GetSpotTradingHistoryReq): Promise<SpotHistoricTradeRecord[]>;
    /**
     * Get server current time
     *
     * @returns Promise<{
     *   server_time: number;
     * }>
     */
    getServerTime(): Promise<{
        server_time: number;
    }>;
    /**
     * Countdown cancel orders
     *
     * When the timeout set by the user is reached, if there is no cancel or set a new countdown, the related pending orders will be automatically cancelled. This endpoint can be called repeatedly to set a new countdown or cancel the countdown.
     *
     * @param params Parameters for setting countdown cancel orders
     * @returns Promise<{
     *   triggerTime: number;
     * }>
     */
    submitSpotCountdownOrders(params: {
        timeout: number;
        currency_pair?: string;
    }): Promise<{
        triggerTime: number;
    }>;
    /**
     * Batch modification of orders
     *
     * Default modification of orders for spot, portfolio, and margin accounts. To modify orders for a cross margin account, the account parameter must be specified as cross_margin. For portfolio margin accounts, the account parameter can only be specified as cross_margin. Currently, only modifications to price or quantity (choose one) are supported.
     *
     * NOTE: The "xGateExptime" parameter will translate to the "x-gate-exptime" header.
     *
     * @param params Parameters for batch modification of orders
     * @returns Promise<Order[]>
     */
    batchUpdateSpotOrders(body: UpdateSpotBatchOrdersReq[], params?: {
        xGateExptime?: number;
    }): Promise<SpotOrder[]>;
    /**
     * Query spot insurance fund historical data
     *
     * @param params Parameters for querying spot insurance fund history
     * @returns Promise<{
     *   currency: string;
     *   balance: string;
     *   time: number;
     * }[]>
     */
    getSpotInsuranceHistory(params: GetSpotInsuranceHistoryReq): Promise<SpotInsuranceHistory[]>;
    /**
     * Create a price-triggered order
     *
     * @param params Parameters for creating a price-triggered order
     * @returns Promise<{
     *   id: number;
     * }>
     */
    submitSpotPriceTriggerOrder(params: SpotPriceTriggeredOrder): Promise<{
        id: number;
    }>;
    /**
     * Retrieve running auto order list
     *
     * @param params Parameters for retrieving running auto order list
     * @returns Promise<SpotPriceTriggeredOrder[]>
     */
    getSpotAutoOrders(params: GetSpotAutoOrdersReq): Promise<SpotPriceTriggeredOrder[]>;
    /**
     * Cancel all open orders
     *
     * @param params Parameters for cancelling all open orders
     * @returns Promise<SpotPriceTriggeredOrder[]>
     */
    cancelAllOpenSpotOrders(params?: {
        market?: string;
        account?: 'normal' | 'margin' | 'cross_margin';
    }): Promise<SpotPriceTriggeredOrder[]>;
    /**
     * Get a price-triggered order
     *
     * @param params Parameters for getting a price-triggered order
     * @returns Promise<SpotPriceTriggeredOrder>
     */
    getPriceTriggeredOrder(params: {
        order_id: string;
    }): Promise<SpotPriceTriggeredOrder>;
    /**
     * Cancel a price-triggered order
     *
     * @param params Parameters for cancelling a price-triggered order
     * @returns Promise<SpotPriceTriggeredOrder>
     */
    cancelSpotTriggeredOrder(params: {
        order_id: string;
    }): Promise<SpotPriceTriggeredOrder>;
    /**==========================================================================================================================
     * MARGIN
     * ==========================================================================================================================
     */
    /**
     * Margin account list
     *
     * @param params Parameters for listing margin accounts
     * @returns Promise<GetMarginAccountsResp[]>
     */
    getMarginAccounts(params?: {
        currency_pair?: string;
    }): Promise<MarginAccount[]>;
    /**
     * List margin account balance change history
     *
     * Only transferals from and to margin account are provided for now. Time range allows 30 days at most.
     *
     * @param params Parameters for listing margin account balance change history
     * @returns Promise<GetMarginBalanceHistoryResp[]>
     */
    getMarginBalanceHistory(params?: GetMarginBalanceHistoryReq): Promise<MarginBalanceHistoryRecord[]>;
    /**
     * Funding account list
     *
     * @param params Parameters for listing funding accounts
     * @returns Promise<{
     *   currency: string;
     *   available: string;
     *   locked: string;
     *   lent: string;
     *   total_lent: string;
     * }[]>
     */
    getFundingAccounts(params?: {
        currency?: string;
    }): Promise<{
        currency: string;
        available: string;
        locked: string;
        lent: string;
        total_lent: string;
    }[]>;
    /**
     * Update user's auto repayment setting
     *
     * @param params Parameters for updating auto repayment setting
     * @returns Promise<{ status: 'on' | 'off' }>
     */
    updateAutoRepaymentSetting(params: {
        status: 'on' | 'off';
    }): Promise<{
        status: 'on' | 'off';
    }>;
    /**
     * Retrieve user auto repayment setting
     *
     * @returns Promise<{ status: 'on' | 'off' }>
     */
    getAutoRepaymentSetting(): Promise<{
        status: 'on' | 'off';
    }>;
    /**
     * Get the max transferable amount for a specific margin currency
     *
     * @param params Parameters for retrieving the max transferable amount
     * @returns Promise<{
     *   currency: string;
     *   currency_pair?: string;
     *   amount: string;
     * }>
     */
    getMarginTransferableAmount(params: {
        currency: string;
        currency_pair?: string;
    }): Promise<{
        currency: string;
        currency_pair?: string;
        amount: string;
    }>;
    /**
     * @deprecated  as of 2025-02-10
     * Currencies supported by cross margin
     *
     * @returns Promise<GetCrossMarginCurrenciesResp[]>
     */
    getCrossMarginCurrencies(): Promise<CrossMarginCurrency[]>;
    /**
     * @deprecated  as of 2025-02-10
     * Retrieve detail of one single currency supported by cross margin
     *
     * @param params Parameters containing the currency name
     * @returns Promise<GetCrossMarginCurrenciesResp>
     */
    getCrossMarginCurrency(params: {
        currency: string;
    }): Promise<CrossMarginCurrency>;
    /**
     * @deprecated  as of 2025-02-10
     * Retrieve cross margin account
     *
     * @returns Promise<GetCrossMarginAccountResp>
     */
    getCrossMarginAccount(): Promise<CrossMarginAccount>;
    /**
     * @deprecated  as of 2025-02-10
     * Retrieve cross margin account change history
     *
     * Record time range cannot exceed 30 days.
     *
     * @param params Parameters for retrieving cross margin account change history
     * @returns Promise<GetCrossMarginAccountHistoryResp[]>
     */
    getCrossMarginAccountHistory(params?: GetCrossMarginAccountHistoryReq): Promise<CrossMarginAccountHistoryRecord[]>;
    /**
     *
     * @deprecated  as of 2025-02-10
     * Create a cross margin borrow loan
     *
     * Borrow amount cannot be less than currency minimum borrow amount.
     *
     * @param params Parameters for creating a cross margin borrow loan
     * @returns Promise<SubmitCrossMarginBorrowLoanResp>
     *
     */
    submitCrossMarginBorrowLoan(params: SubmitCrossMarginBorrowLoanReq): Promise<CrossMarginMorrowLoanRecord>;
    /**
     *
     * List cross margin borrow history
     *
     * Sort by creation time in descending order by default. Set reverse=false to return ascending results.
     *
     * @param params Parameters for listing cross margin borrow history
     * @returns Promise<SubmitCrossMarginBorrowLoanResp[]>
     */
    getCrossMarginBorrowHistory(params: GetCrossMarginBorrowHistoryReq): Promise<CrossMarginMorrowLoanRecord[]>;
    /**
     * @deprecated  as of 2025-02-10
     * Retrieve single borrow loan detail
     *
     * @param params Parameters containing the borrow loan ID
     * @returns Promise<SubmitCrossMarginBorrowLoanResp>
     */
    getCrossMarginBorrowLoan(params: {
        loan_id: string;
    }): Promise<CrossMarginMorrowLoanRecord>;
    /**
     * @deprecated  as of 2025-02-10
     * Cross margin repayments
     *
     * When the liquidity of the currency is insufficient and the transaction risk is high, the currency will be disabled, and funds cannot be transferred. When the available balance of cross-margin is insufficient, the balance of the spot account can be used for repayment. Please ensure that the balance of the spot account is sufficient, and system uses cross-margin account for repayment first.
     *
     * @param params Parameters for cross margin repayments
     * @returns Promise<SubmitCrossMarginBorrowLoanResp[]>
     */
    submitCrossMarginRepayment(params: {
        currency: string;
        amount: string;
    }): Promise<CrossMarginMorrowLoanRecord[]>;
    /**
     * @deprecated  as of 2025-02-10
     * Retrieve cross margin repayments
     *
     * Sort by creation time in descending order by default. Set reverse=false to return ascending results.
     *
     * @param params Parameters for retrieving cross margin repayments
     * @returns Promise<GetCrossMarginRepaymentsResp[]>
     */
    getCrossMarginRepayments(params?: GetCrossMarginRepaymentsReq): Promise<CrossMarginAccount[]>;
    /**
     * @deprecated  as of 2025-02-10
     * Interest records for the cross margin account
     *
     * @param params Parameters for retrieving interest records
     * @returns Promise<GetCrossMarginInterestRecordsResp[]>
     */
    getCrossMarginInterestRecords(params?: GetCrossMarginInterestRecordsReq): Promise<GetCrossMarginInterestRecordsReq[]>;
    /**
     * @deprecated  as of 2025-02-10
     * Get the max transferable amount for a specific cross margin currency
     *
     * @param params Parameters for retrieving the max transferable amount
     * @returns Promise<{
     *   currency: string;
     *   amount: string;
     * }>
     */
    getCrossMarginTransferableAmount(params: {
        currency: string;
    }): Promise<{
        currency: string;
        amount: string;
    }>;
    /**
     * @deprecated  as of 2025-02-10
     * Estimated interest rates
     *
     * Please note that the interest rates are subject to change based on the borrowing and lending demand, and therefore, the provided rates may not be entirely accurate.
     *
     * @param params Parameters for retrieving estimated interest rates
     * @returns Promise<any>
     */
    getEstimatedInterestRates(params: {
        currencies: string[];
    }): Promise<any>;
    /**
     * @deprecated  as of 2025-02-10
     * Get the max borrowable amount for a specific cross margin currency
     *
     * @param params Parameters for retrieving the max borrowable amount
     * @returns Promise<{
     *   currency: string;
     *   amount: string;
     * }>
     */
    getCrossMarginBorrowableAmount(params: {
        currency: string;
    }): Promise<{
        currency: string;
        amount: string;
    }>;
    /**==========================================================================================================================
     * MARGIN UNI
     * ==========================================================================================================================
     */
    /**
     * List lending markets
     *
     * @returns Promise<GetLendingMarketsResp[]>
     */
    getLendingMarkets(): Promise<LendingMarket[]>;
    /**
     * Get detail of lending market
     *
     * @param params Parameters containing the currency pair
     * @returns Promise<{
     *   currency_pair: string;
     *   base_min_borrow_amount: string;
     *   quote_min_borrow_amount: string;
     *   leverage: string;
     * }>
     */
    getLendingMarket(params: {
        currency_pair: string;
    }): Promise<LendingMarket>;
    /**
     * Estimate interest rate
     *
     * Please note that the interest rates are subject to change based on the borrowing and lending demand, and therefore, the provided rates may not be entirely accurate.
     *
     * @param params Parameters for retrieving estimated interest rates
     * @returns Promise<any>
     */
    getEstimatedInterestRate(params: {
        currencies: string[];
    }): Promise<any>;
    /**
     * Borrow or repay
     *
     * @param params Parameters for borrowing or repaying
     * @returns Promise<any>
     */
    submitMarginUNIBorrowOrRepay(params: {
        currency: string;
        type: 'borrow' | 'repay';
        amount: string;
        currency_pair: string;
        repaid_all?: boolean;
    }): Promise<any>;
    /**
     * List loans
     *
     * @param params Parameters for listing loans
     * @returns Promise<GetMarginUNILoansResp[]>
     */
    getMarginUNILoans(params?: GetMarginUNILoansReq): Promise<MarginUNILoan[]>;
    /**
     * Get loan records
     *
     * @param params Parameters for retrieving loan records
     * @returns Promise<GetMarginUNILoanRecordsResp[]>
     */
    getMarginUNILoanRecords(params?: GetMarginUNILoanRecordsReq): Promise<MarginUNILoanRecord[]>;
    /**
     * List interest records
     *
     * @param params Parameters for listing interest records
     * @returns Promise<GetMarginUNIInterestRecordsResp[]>
     */
    getMarginUNIInterestRecords(params?: GetMarginUNIInterestRecordsReq): Promise<MarginUNIInterestRecord[]>;
    /**
     * Get maximum borrowable
     *
     * @param params Parameters for retrieving the maximum borrowable amount
     * @returns Promise<GetMarginUNIMaxBorrowResp>
     */
    getMarginUNIMaxBorrow(params: GetMarginUNIMaxBorrowReq): Promise<MarginUNIMaxBorrowable>;
    /**==========================================================================================================================
     * FLASH SWAP
     * ==========================================================================================================================
     */
    /**
     * List All Supported Currency Pairs In Flash Swap
     *
     * @param params Parameters for retrieving data of the specified currency
     * @returns Promise<GetFlashSwapCurrencyPairsResp[]>
     */
    getFlashSwapCurrencyPairs(params?: {
        currency?: string;
        page?: number;
        limit?: number;
    }): Promise<FlashSwapCurrencyPair[]>;
    /**
     * Create a flash swap order
     *
     * Initiate a flash swap preview in advance because order creation requires a preview result.
     *
     * @param params Parameters for creating a flash swap order
     * @returns Promise<SubmitFlashSwapOrderResp>
     */
    submitFlashSwapOrder(params: SubmitFlashSwapOrderReq): Promise<FlashSwapOrder>;
    /**
     * List all flash swap orders
     *
     * @param params Parameters for listing flash swap orders
     * @returns Promise<GetFlashSwapOrdersResp[]>
     */
    getFlashSwapOrders(params?: GetFlashSwapOrdersReq): Promise<FlashSwapOrder[]>;
    /**
     * Get a single flash swap order's detail
     *
     * @param params Parameters containing the flash swap order ID
     * @returns Promise<GetFlashSwapOrderResp>
     */
    getFlashSwapOrder(params: {
        order_id: number;
    }): Promise<FlashSwapOrder>;
    /**
     * Initiate a flash swap order preview
     *
     * @param params Parameters for initiating a flash swap order preview
     * @returns Promise<SubmitFlashSwapOrderPreviewResp>
     */
    submitFlashSwapOrderPreview(params: SubmitFlashSwapOrderPreviewReq): Promise<SubmitFlashSwapOrderPreviewResp>;
    /**==========================================================================================================================
     * FUTURES
     * ==========================================================================================================================
     */
    /**
     * List all futures contracts
     *
     * @param params Parameters for listing futures contracts
     * @returns Promise<Contract[]>
     */
    getFuturesContracts(params: {
        settle: 'btc' | 'usdt' | 'usd';
        limit?: number;
        offset?: number;
    }): Promise<FuturesContract[]>;
    /**
     * Get a single contract
     *
     * @param params Parameters for retrieving a single contract
     * @returns Promise<Contract>
     */
    getFuturesContract(params: {
        settle: 'btc' | 'usdt' | 'usd';
        contract: string;
    }): Promise<FuturesContract>;
    /**
     * Futures order book
     *
     * Bids will be sorted by price from high to low, while asks sorted reversely.
     *
     * @param params Parameters for retrieving the futures order book
     * @returns Promise<GetFuturesOrderBookResp>
     */
    getFuturesOrderBook(params: GetFuturesOrderBookReq): Promise<FuturesOrderBook>;
    /**
     * Futures trading history
     *
     * @param params Parameters for retrieving futures trading history
     * @returns Promise<GetFuturesTradesResp[]>
     */
    getFuturesTrades(params: GetFuturesTradesReq): Promise<FuturesTrade[]>;
    /**
     * Get futures Candles
     *
     * Return specified contract Candles. If prefix contract with mark_, the contract's mark price Candles are returned; if prefix with index_, index price Candles will be returned.
     *
     * Maximum of 2000 points are returned in one query. Be sure not to exceed the limit when specifying from, to and interval.
     *
     * @param params Parameters for retrieving futures Candles
     * @returns Promise<GetFuturesCandlesResp[]>
     */
    getFuturesCandles(params: GetFuturesCandlesReq): Promise<FuturesCandle[]>;
    /**
     * Premium Index K-Line
     *
     * Maximum of 1000 points can be returned in a query. Be sure not to exceed the limit when specifying from, to and interval.
     *
     * @param params Parameters for retrieving premium index K-Line
     * @returns Promise<GetPremiumIndexKLineResp[]>
     */
    getPremiumIndexKLines(params: GetFuturesCandlesReq): Promise<PremiumIndexKLine[]>;
    /**
     * List futures tickers
     *
     * @param params Parameters for listing futures tickers
     * @returns Promise<GetFuturesTickersResp[]>
     */
    getFuturesTickers(params: {
        settle: 'btc' | 'usdt' | 'usd';
        contract?: string;
    }): Promise<FuturesTicker[]>;
    /**
     * Funding rate history
     *
     * @param params Parameters for retrieving funding rate history
     * @returns Promise<{
     *   t: number;
     *   r: string;
     * }[]>
     */
    getFundingRates(params: GetFundingRatesReq): Promise<{
        t: number;
        r: string;
    }[]>;
    /**
     * Futures insurance balance history
     *
     * @param params Parameters for retrieving futures insurance balance history
     * @returns Promise<{
     *   t: number;
     *   b: string;
     * }[]>
     */
    getFuturesInsuranceBalanceHistory(params: {
        settle: 'btc' | 'usdt' | 'usd';
        limit?: number;
    }): Promise<{
        t: number;
        b: string;
    }[]>;
    /**
     * Futures stats
     *
     * @param params Parameters for retrieving futures stats
     * @returns Promise<GetFuturesStatsResp[]>
     */
    getFuturesStats(params: GetFuturesStatsReq): Promise<FuturesStats[]>;
    /**
     * Get index constituents
     *
     * @param params Parameters for retrieving index constituents
     * @returns Promise<GetIndexConstituentsResp>
     */
    getIndexConstituents(params: {
        settle: 'btc' | 'usdt' | 'usd';
        index: string;
    }): Promise<IndexConstituents>;
    /**
     * Retrieve liquidation history
     *
     * Interval between from and to cannot exceed 3600. Some private fields will not be returned in public endpoints. Refer to field description for detail.
     *
     * @param params Parameters for retrieving liquidation history
     * @returns Promise<GetLiquidationHistoryResp[]>
     */
    getLiquidationHistory(params: GetLiquidationHistoryReq): Promise<LiquidationHistoryRecord[]>;
    /**
     * List risk limit tiers
     *
     * When the 'contract' parameter is not passed, the default is to query the risk limits for the top 100 markets.
     * 'Limit' and 'offset' correspond to pagination queries at the market level, not to the length of the returned array.
     * This only takes effect when the 'contract' parameter is empty.
     *
     * @param params Parameters for listing risk limit tiers
     * @returns Promise<GetRiskLimitTiersResp[]>
     */
    getRiskLimitTiers(params: GetRiskLimitTiersReq): Promise<RiskLimitTier[]>;
    /**
     * Query futures account
     *
     * @param params Parameters for querying futures account
     * @returns Promise<GetFuturesAccountResp>
     */
    getFuturesAccount(params: {
        settle: 'btc' | 'usdt' | 'usd';
    }): Promise<FuturesAccount>;
    /**
     * Query account book
     *
     * If the contract field is provided, it can only filter records that include this field after 2023-10-30.
     *
     * @param params Parameters for querying account book
     * @returns Promise<GetFuturesAccountBookResp[]>
     */
    getFuturesAccountBook(params: GetFuturesAccountBookReq): Promise<FuturesAccountBookRecord[]>;
    /**
     * List all positions of a user
     *
     * @param params Parameters for listing all positions of a user
     * @returns Promise<Position[]>
     */
    getFuturesPositions(params: GetFuturesPositionsReq): Promise<FuturesPosition[]>;
    /**
     * Get single position
     *
     * @param params Parameters for retrieving a single position
     * @returns Promise<Position>
     */
    getFuturesPosition(params: {
        settle: 'btc' | 'usdt' | 'usd';
        contract: string;
    }): Promise<FuturesPosition>;
    /**
     * Update position margin
     *
     * @param params Parameters for updating position margin
     * @returns Promise<Position>
     */
    updateFuturesMargin(params: {
        settle: 'btc' | 'usdt' | 'usd';
        contract: string;
        change: string;
    }): Promise<FuturesPosition>;
    /**
     * Update position leverage
     *
     * @param params Parameters for updating position leverage
     * @returns Promise<Position>
     */
    updateFuturesLeverage(params: {
        settle: 'btc' | 'usdt' | 'usd';
        contract: string;
        leverage: string;
        cross_leverage_limit?: string;
    }): Promise<FuturesPosition>;
    /**
     * Update position risk limit
     *
     * @param params Parameters for updating position risk limit
     * @returns Promise<Position>
     */
    updatePositionRiskLimit(params: {
        settle: 'btc' | 'usdt' | 'usd';
        contract: string;
        risk_limit: string;
    }): Promise<FuturesPosition>;
    /**
     * Enable or disable dual mode
     *
     * Before setting dual mode, make sure all positions are closed and no orders are open.
     *
     * @param params Parameters for enabling or disabling dual mode
     * @returns Promise<FuturesAccount>
     */
    updateFuturesDualMode(params: {
        settle: 'btc' | 'usdt' | 'usd';
        dual_mode: boolean;
    }): Promise<FuturesAccount>;
    /**
     * Retrieve position detail in dual mode
     *
     * @param params Parameters for retrieving position detail in dual mode
     * @returns Promise<Position[]>
     */
    getDualModePosition(params: {
        settle: 'btc' | 'usdt' | 'usd';
        contract: string;
    }): Promise<FuturesPosition[]>;
    /**
     * Update position margin in dual mode
     *
     * @param params Parameters for updating position margin in dual mode
     * @returns Promise<Position[]>
     */
    updateDualModePositionMargin(params: UpdateDualModePositionMarginReq): Promise<FuturesPosition[]>;
    /**
     * Update position leverage in dual mode
     *
     * @param params Parameters for updating position leverage in dual mode
     * @returns Promise<Position[]>
     */
    updateDualModePositionLeverage(params: UpdateDualModePositionLeverageReq): Promise<FuturesPosition[]>;
    /**
     * Update position risk limit in dual mode
     *
     * @param params Parameters for updating position risk limit in dual mode
     * @returns Promise<Position[]>
     */
    updateDualModePositionRiskLimit(params: {
        settle: 'btc' | 'usdt' | 'usd';
        contract: string;
        risk_limit: string;
    }): Promise<FuturesPosition[]>;
    /**
     * Create a futures order
     *
     * Creating futures orders requires size, which is the number of contracts instead of currency amount. You can use quanto_multiplier in the contract detail response to know how much currency 1 size contract represents.
     * Zero-filled order cannot be retrieved 10 minutes after order cancellation. You will get a 404 not found for such orders.
     * Set reduce_only to true to keep the position from changing side when reducing position size.
     * In single position mode, to close a position, you need to set size to 0 and close to true.
     * In dual position mode, to close one side position, you need to set auto_size side, reduce_only to true, and size to 0.
     * Set stp_act to decide the strategy of self-trade prevention. For detailed usage, refer to the stp_act parameter in the request body.
     *
     * NOTE: The "xGateExptime" parameter will translate to the "x-gate-exptime" header.
     *
     * @param params Parameters for creating a futures order
     * @returns Promise<FuturesOrder>
     */
    submitFuturesOrder(params: SubmitFuturesOrderReq): Promise<FuturesOrder>;
    /**
     * List futures orders
     *
     * Zero-fill order cannot be retrieved for 10 minutes after cancellation.
     * Historical orders, by default, only data within the past 6 months is supported. If you need to query data for a longer period, please use GET /futures/{settle}/orders_timerange.
     *
     * @param params Parameters for listing futures orders
     * @returns Promise<FuturesOrder[]>
     */
    getFuturesOrders(params: GetFuturesOrdersReq): Promise<FuturesOrder[]>;
    /**
     * Cancel all open orders matched
     *
     * Zero-filled order cannot be retrieved 10 minutes after order cancellation.
     *
     * NOTE: The "xGateExptime" parameter will translate to the "x-gate-exptime" header.
     *
     * @param params Parameters for cancelling all open orders matched
     * @returns Promise<FuturesOrder[]>
     */
    cancelAllFuturesOrders(params: DeleteAllFuturesOrdersReq): Promise<FuturesOrder[]>;
    /**
     * List Futures Orders By Time Range
     *
     * @param params Parameters for listing futures orders by time range
     * @returns Promise<FuturesOrder[]>
     */
    getFuturesOrdersByTimeRange(params: GetFuturesOrdersByTimeRangeReq): Promise<FuturesOrder[]>;
    /**
     * Create a batch of futures orders
     *
     * Up to 10 orders per request.
     * If any of the order's parameters are missing or in the wrong format, all of them will not be executed, and a http status 400 error will be returned directly.
     * If the parameters are checked and passed, all are executed. Even if there is a business logic error in the middle (such as insufficient funds), it will not affect other execution orders.
     * The returned result is in array format, and the order corresponds to the orders in the request body.
     * In the returned result, the succeeded field of type bool indicates whether the execution was successful or not.
     * If the execution is successful, the normal order content is included; if the execution fails, the label field is included to indicate the cause of the error.
     * In the rate limiting, each order is counted individually.
     *
     * NOTE: The "xGateExptime" parameter will translate to the "x-gate-exptime" header.
     *
     * @param params Parameters for creating a batch of futures orders
     * @returns Promise<FuturesOrder[]>
     */
    submitFuturesBatchOrders(params: {
        xGateExptime?: number;
        settle: 'btc' | 'usdt' | 'usd';
        orders: SubmitFuturesOrderReq[];
    }): Promise<FuturesOrder[]>;
    /**
     * Get a single order
     *
     * Zero-fill order cannot be retrieved for 10 minutes after cancellation.
     * Historical orders, by default, only data within the past 6 months is supported.
     *
     * @param params Parameters for retrieving a single order
     * @returns Promise<FuturesOrder>
     */
    getFuturesOrder(params: {
        settle: 'btc' | 'usdt' | 'usd';
        order_id: string;
    }): Promise<FuturesOrder>;
    /**
     * Cancel a single order
     *
     * NOTE: The "xGateExptime" parameter will translate to the "x-gate-exptime" header.
     *
     * @param params Parameters for cancelling a single order
     * @returns Promise<FuturesOrder>
     */
    cancelFuturesOrder(params: {
        xGateExptime?: number;
        settle: 'btc' | 'usdt' | 'usd';
        order_id: string;
    }): Promise<FuturesOrder>;
    /**
     * Amend an order
     *
     * NOTE: The "xGateExptime" parameter will translate to the "x-gate-exptime" header.
     *
     * @param params Parameters for amending an order
     * @returns Promise<FuturesOrder>
     */
    updateFuturesOrder(params: UpdateFuturesOrderReq): Promise<FuturesOrder>;
    /**
     * List personal trading history
     *
     * By default, only data within the past 6 months is supported. If you need to query data for a longer period, please use GET /futures/{settle}/my_trades_timerange.
     *
     * @param params Parameters for listing personal trading history
     * @returns Promise<GetFuturesTradingHistoryResp[]>
     */
    getFuturesTradingHistory(params: GetFuturesTradingHistoryReq): Promise<FuturesTradingHistoryRecord[]>;
    /**
     * List personal trading history
     *
     * This endpoint is for data longer than 6 months.
     *
     * @param params Parameters for listing personal trading history
     * @returns Promise<GetFuturesTradingHistoryResp[]>
     */
    getFuturesTradingHistoryByTimeRange(params: GetFuturesTradingHistoryByTimeRangeReq): Promise<FuturesTradingHistoryRecord[]>;
    /**
     * List position close history
     *
     * @param params Parameters for listing position close history
     * @returns Promise<GetFuturesPositionHistoryResp[]>
     */
    getFuturesPositionHistory(params: GetFuturesPositionHistoryReq): Promise<FuturesPositionHistoryRecord[]>;
    /**
     * List liquidation history
     *
     * @param params Parameters for listing liquidation history
     * @returns Promise<GetFuturesLiquidationHistoryResp[]>
     */
    getFuturesLiquidationHistory(params: GetFuturesLiquidationHistoryReq): Promise<FuturesLiquidationHistoryRecord[]>;
    /**
     * List Auto-Deleveraging History
     *
     * @param params Parameters for listing auto-deleveraging history
     * @returns Promise<GetFuturesAutoDeleveragingHistoryResp[]>
     */
    getFuturesAutoDeleveragingHistory(params: GetFuturesLiquidationHistoryReq): Promise<FuturesAutoDeleveragingHistoryRecord[]>;
    /**
     * Countdown cancel orders
     *
     * When the timeout set by the user is reached, if there is no cancel or set a new countdown, the related pending orders will be automatically cancelled. This endpoint can be called repeatedly to set a new countdown or cancel the countdown.
     * For example, call this endpoint at 30s intervals, each countdown timeout is set to 30s. If this endpoint is not called again within 30 seconds, all pending orders on the specified market will be automatically cancelled, if no market is specified, all market pending orders will be cancelled.
     * If the timeout is set to 0 within 30 seconds, the countdown timer will expire and the cancel function will be cancelled.
     *
     * @param params Parameters for setting countdown cancel orders
     * @returns Promise<{ triggerTime: number }>
     */
    setFuturesOrderCancelCountdown(params: {
        settle: 'btc' | 'usdt' | 'usd';
        timeout: number;
        contract?: string;
    }): Promise<{
        triggerTime: number;
    }>;
    /**
     * Query user trading fee rates
     *
     * @param params Parameters for querying user trading fee rates
     * @returns Promise<any>
     */
    getFuturesUserTradingFees(params: {
        settle: 'btc' | 'usdt' | 'usd';
        contract?: string;
    }): Promise<any>;
    /**
     * Cancel a batch of orders with an ID list
     *
     * Multiple distinct order ID list can be specified. Each request can cancel a maximum of 20 records.
     *
     * NOTE: The "xGateExptime" parameter will translate to the "x-gate-exptime" header.
     *
     * @param params Parameters for cancelling a batch of orders with an ID list
     * @returns Promise<DeleteFuturesBatchOrdersResp[]>
     */
    batchCancelFuturesOrders(params: {
        xGateExptime?: number;
        settle: 'btc' | 'usdt' | 'usd';
        orderIds: string[];
    }): Promise<DeleteFuturesBatchOrdersResp[]>;
    /**
     * Batch modify orders with specified IDs
     *
     * You can specify multiple different order IDs. You can only modify up to 10 orders in one request.
     *
     * NOTE: The "xGateExptime" parameter will translate to the "x-gate-exptime" header.
     *
     * @param params Array of BatchAmendOrderReq objects
     * @param settle Settlement currency (e.g., 'btc', 'usdt', 'usd')
     * @returns Promise<BatchAmendOrderResp[]>
     */
    batchUpdateFuturesOrders(params: {
        xGateExptime?: number;
        settle: 'btc' | 'usdt' | 'usd';
        orders: BatchAmendOrderReq[];
    }): Promise<BatchAmendOrderResp[]>;
    /**
     * Create a price-triggered order
     *
     * @param params Parameters for creating a price-triggered order
     * @returns Promise<{ id: number }>
     */
    submitFuturesPriceTriggeredOrder(params: SubmitFuturesTriggeredOrderReq): Promise<{
        id: number;
    }>;
    /**
     * List all auto orders
     *
     * @param params Parameters for listing all auto orders
     * @returns Promise<FuturesPriceTriggeredOrder[]>
     */
    getFuturesAutoOrders(params: GetFuturesAutoOrdersReq): Promise<FuturesPriceTriggeredOrder[]>;
    /**
     * Cancel all open orders
     *
     * @param params Parameters for cancelling all open orders
     * @returns Promise<FuturesPriceTriggeredOrder[]>
     */
    cancelAllOpenFuturesOrders(params: {
        settle: 'btc' | 'usdt' | 'usd';
        contract: string;
    }): Promise<FuturesPriceTriggeredOrder[]>;
    /**
     * Get a price-triggered order
     *
     * @param params Parameters for retrieving a price-triggered order
     * @returns Promise<FuturesPriceTriggeredOrder>
     */
    getFuturesPriceTriggeredOrder(params: {
        settle: 'btc' | 'usdt' | 'usd';
        order_id: string;
    }): Promise<FuturesPriceTriggeredOrder>;
    /**
     * Cancel a price-triggered order
     *
     * @param params Parameters for cancelling a price-triggered order
     * @returns Promise<FuturesPriceTriggeredOrder>
     */
    cancelFuturesPriceTriggeredOrder(params: {
        settle: 'btc' | 'usdt' | 'usd';
        order_id: string;
    }): Promise<FuturesPriceTriggeredOrder>;
    /**==========================================================================================================================
     * DELIVERY
     * ==========================================================================================================================
     */
    /**
     * List all futures contracts
     *
     * @param params Parameters for listing all futures contracts
     * @returns Promise<DeliveryContract[]>
     */
    getAllDeliveryContracts(params: {
        settle: 'usdt';
    }): Promise<FuturesDeliveryContract[]>;
    /**
     * Get a single contract
     *
     * @param params Parameters for retrieving a single contract
     * @returns Promise<DeliveryContract>
     */
    getDeliveryContract(params: {
        settle: 'usdt';
        contract: string;
    }): Promise<FuturesDeliveryContract>;
    /**
     * Futures order book
     *
     * Bids will be sorted by price from high to low, while asks sorted reversely
     *
     * @param params Parameters for retrieving the futures order book
     * @returns Promise<GetDeliveryOrderBookResp>
     */
    getDeliveryOrderBook(params: GetDeliveryOrderBookReq): Promise<DeliveryOrderBook>;
    /**
     * Futures trading history
     *
     * @param params Parameters for retrieving the futures trading history
     * @returns Promise<GetDeliveryTradesResp[]>
     */
    getDeliveryTrades(params: GetDeliveryTradesReq): Promise<DeliveryTrade[]>;
    /**
     * Get futures Candles
     *
     * Return specified contract Candles. If prefix contract with mark_, the contract's mark price Candles are returned; if prefix with index_, index price Candles will be returned.
     * Maximum of 2000 points are returned in one query. Be sure not to exceed the limit when specifying from, to and interval.
     *
     * @param params Parameters for retrieving futures Candles
     * @returns Promise<GetDeliveryCandlesResp[]>
     */
    getDeliveryCandles(params: GetDeliveryCandlesReq): Promise<DeliveryCandle[]>;
    /**
     * List futures tickers
     *
     * @param params Parameters for listing futures tickers
     * @returns Promise<GetDeliveryTickersResp[]>
     */
    getDeliveryTickers(params: {
        settle: 'usdt';
        contract?: string;
    }): Promise<DeliveryTicker[]>;
    /**
     * Futures insurance balance history
     *
     * @param params Parameters for retrieving the futures insurance balance history
     * @returns Promise<{
     *   t: number;
     *   b: string;
     * }[]>
     */
    getDeliveryInsuranceBalanceHistory(params: {
        settle: 'usdt';
        limit?: number;
    }): Promise<{
        t: number;
        b: string;
    }[]>;
    /**
     * Query futures account
     *
     * @param params Parameters for querying futures account
     * @returns Promise<GetDeliveryAccountResp>
     */
    getDeliveryAccount(params: {
        settle: 'usdt';
    }): Promise<DeliveryAccount>;
    /**
     * Query account book
     *
     * @param params Parameters for querying account book
     * @returns Promise<GetDeliveryBookResp[]>
     */
    getDeliveryBook(params: GetDeliveryBookReq): Promise<DeliveryBook[]>;
    /**
     * List all positions of a user
     *
     * @param params Parameters for listing all positions of a user
     * @returns Promise<Position[]>
     */
    getDeliveryPositions(params: {
        settle: 'usdt';
    }): Promise<FuturesPosition[]>;
    /**
     * Get single position
     *
     * @param params Parameters for retrieving a single position
     * @returns Promise<Position>
     */
    getDeliveryPosition(params: {
        settle: 'usdt';
        contract: string;
    }): Promise<FuturesPosition>;
    /**
     * Update position margin
     *
     * @param params Parameters for updating position margin
     * @returns Promise<Position>
     */
    updateDeliveryMargin(params: {
        settle: 'usdt';
        contract: string;
        change: string;
    }): Promise<FuturesPosition>;
    /**
     * Update position leverage
     *
     * @param params Parameters for updating position leverage
     * @returns Promise<Position>
     */
    updateDeliveryLeverage(params: {
        settle: 'usdt';
        contract: string;
        leverage: string;
    }): Promise<FuturesPosition>;
    /**
     * Update position risk limit
     *
     * @param params Parameters for updating position risk limit
     * @returns Promise<Position>
     */
    updateDeliveryRiskLimit(params: {
        settle: 'usdt';
        contract: string;
        risk_limit: string;
    }): Promise<FuturesPosition>;
    /**
     * Create a futures order
     *
     * Zero-filled order cannot be retrieved 10 minutes after order cancellation
     *
     * @param params Parameters for creating a futures order
     * @returns Promise<FuturesOrder>
     */
    submitDeliveryOrder(params: SubmitDeliveryFuturesOrderReq): Promise<FuturesOrder>;
    /**
     * List futures orders
     *
     * Zero-fill order cannot be retrieved 10 minutes after order cancellation.
     *
     * @param params Parameters for listing futures orders
     * @returns Promise<FuturesOrder[]>
     */
    getDeliveryOrders(params: GetDeliveryOrdersReq): Promise<FuturesOrder[]>;
    /**
     * Cancel all open orders matched
     *
     * Zero-filled order cannot be retrieved 10 minutes after order cancellation
     *
     * @param params Parameters for cancelling all open orders matched
     * @returns Promise<FuturesOrder[]>
     */
    cancelAllDeliveryOrders(params: {
        settle: 'usdt';
        contract: string;
        side?: 'ask' | 'bid';
    }): Promise<FuturesOrder[]>;
    /**
     * Get a single order
     *
     * Zero-filled order cannot be retrieved 10 minutes after order cancellation
     *
     * @param params Parameters for retrieving a single order
     * @returns Promise<FuturesOrder>
     */
    getDeliveryOrder(params: {
        settle: 'usdt';
        order_id: string;
    }): Promise<FuturesOrder>;
    /**
     * Cancel a single order
     *
     * @param params Parameters for cancelling a single order
     * @returns Promise<FuturesOrder>
     */
    cancelDeliveryOrder(params: {
        settle: 'usdt';
        order_id: string;
    }): Promise<FuturesOrder>;
    /**
     * List personal trading history
     *
     * @param params Parameters for listing personal trading history
     * @returns Promise<GetDeliveryTradingHistoryResp[]>
     */
    getDeliveryTradingHistory(params: GetDeliveryTradingHistoryReq): Promise<DeliveryTradingHistoryRecord[]>;
    /**
     * List position close history
     *
     * @param params Parameters for listing position close history
     * @returns Promise<GetDeliveryClosedPositionsResp[]>
     */
    getDeliveryClosedPositions(params: GetDeliveryClosedPositionsReq): Promise<DeliveryClosedPosition[]>;
    /**
     * List liquidation history
     *
     * @param params Parameters for listing liquidation history
     * @returns Promise<GetDeliveryLiquidationHistoryResp[]>
     */
    getDeliveryLiquidationHistory(params: GetDeliveryLiquidationHistoryReq): Promise<DeliveryLiquidationHistoryRecord[]>;
    /**
     * List settlement history
     *
     * @param params Parameters for listing settlement history
     * @returns Promise<GetDeliverySettlementHistoryResp[]>
     */
    getDeliverySettlementHistory(params: GetDeliverySettlementHistoryReq): Promise<DeliverySettlementHistoryRecord[]>;
    /**
     * Create a price-triggered order
     *
     * @param params Parameters for creating a price-triggered order
     * @returns Promise<{ id: number }>
     */
    submitDeliveryTriggeredOrder(params: SubmitFuturesTriggeredOrderReq): Promise<{
        id: number;
    }>;
    /**
     * List all auto orders
     *
     * @param params Parameters for listing all auto orders
     * @returns Promise<FuturesPriceTriggeredOrder[]>
     */
    getDeliveryAutoOrders(params: GetDeliveryAutoOrdersReq): Promise<FuturesPriceTriggeredOrder[]>;
    /**
     * Cancel all open orders
     *
     * @param params Parameters for cancelling all open orders
     * @returns Promise<FuturesPriceTriggeredOrder[]>
     */
    cancelAllOpenDeliveryOrders(params: {
        settle: 'usdt';
        contract: string;
    }): Promise<FuturesPriceTriggeredOrder[]>;
    /**
     * Get a price-triggered order
     *
     * @param params Parameters for retrieving a price-triggered order
     * @returns Promise<FuturesPriceTriggeredOrder>
     */
    getDeliveryTriggeredOrder(params: {
        settle: 'usdt';
        order_id: string;
    }): Promise<FuturesPriceTriggeredOrder>;
    /**
     * Cancel a price-triggered order
     *
     * @param params Parameters for cancelling a price-triggered order
     * @returns Promise<FuturesPriceTriggeredOrder>
     */
    cancelTriggeredDeliveryOrder(params: {
        settle: 'usdt';
        order_id: string;
    }): Promise<FuturesPriceTriggeredOrder>;
    /**==========================================================================================================================
     * OPTIONS
     * ==========================================================================================================================
     */
    /**
     * List all underlyings
     *
     * @returns Promise<{ name: string; index_price: string }[]>
     */
    getOptionsUnderlyings(): Promise<{
        name: string;
        index_price: string;
    }[]>;
    /**
     * List all expiration times
     *
     * @param params Parameters for listing expiration times
     * @returns Promise<number[]>
     */
    getOptionsExpirationTimes(params: {
        underlying: string;
    }): Promise<number[]>;
    /**
     * List all the contracts with specified underlying and expiration time
     *
     * @param params Parameters for listing contracts
     * @returns Promise<GetOptionsContractsResp[]>
     */
    getOptionsContracts(params: {
        underlying: string;
        expiration?: number;
    }): Promise<OptionsContract[]>;
    /**
     * Query specified contract detail
     *
     * @param params Parameters for querying specified contract detail
     * @returns Promise<GetOptionsContractsResp>
     */
    getOptionsContract(params: {
        contract: string;
    }): Promise<OptionsContract>;
    /**
     * List settlement history
     *
     * @param params Parameters for listing settlement history
     * @returns Promise<GetOptionsSettlementHistoryResp[]>
     */
    getOptionsSettlementHistory(params: GetOptionsSettlementHistoryReq): Promise<OptionsSettlementHistoryRecord[]>;
    /**
     * Get specified contract's settlement
     *
     * @param params Parameters for retrieving specified contract's settlement
     * @returns Promise<GetOptionsSettlementHistoryResp}>
     */
    getOptionsContractSettlement(params: {
        contract: string;
        underlying: string;
        at: number;
    }): Promise<OptionsSettlementHistoryRecord>;
    /**
     * List my options settlements
     *
     * @param params Parameters for listing my options settlements
     * @returns Promise<GetOptionsMySettlementsResp[]>
     */
    getOptionsMySettlements(params: GetOptionsMySettlementsReq): Promise<OptionsUserSettlement[]>;
    /**
     * Options order book
     *
     * Bids will be sorted by price from high to low, while asks sorted reversely
     *
     * @param params Parameters for retrieving options order book
     * @returns Promise<GetOptionsOrderBookResp>
     */
    getOptionsOrderBook(params: GetOptionsOrderBookReq): Promise<OptionsOrderBook>;
    /**
     * List tickers of options contracts
     *
     * @param params Parameters for listing tickers of options contracts
     * @returns Promise<GetOptionsTickersResp[]>
     */
    getOptionsTickers(params: {
        underlying: string;
    }): Promise<OptionsTicker[]>;
    /**
     * Get underlying ticker
     *
     * @param params Parameters for retrieving underlying ticker
     * @returns Promise<{
     *   trade_put: number;
     *   trade_call: number;
     *   index_price: string;
     * }>
     */
    getOptionsUnderlyingTicker(params: {
        underlying: string;
    }): Promise<{
        trade_put: number;
        trade_call: number;
        index_price: string;
    }>;
    /**
     * Get options Candles
     *
     * @param params Parameters for retrieving options Candles
     * @returns Promise<GetOptionsCandlesResp[]>
     */
    getOptionsCandles(params: GetOptionsCandlesReq): Promise<OptionsCandle[]>;
    /**
     * Mark price Candles of an underlying
     *
     * @param params Parameters for retrieving mark price Candles of an underlying
     * @returns Promise<GetOptionsUnderlyingCandlesResp[]>
     */
    getOptionsUnderlyingCandles(params: GetOptionsUnderlyingCandlesReq): Promise<OptionsUnderlyingCandle[]>;
    /**
     * Options trade history
     *
     * @param params Parameters for retrieving options trade history
     * @returns Promise<GetOptionsTradesResp[]>
     */
    getOptionsTrades(params: GetOptionsTradesReq): Promise<OptionsTrade[]>;
    /**
     * List options account
     *
     * @returns Promise<GetOptionsAccountResp>
     */
    getOptionsAccount(): Promise<OptionsAccount>;
    /**
     * List account changing history
     *
     * @param params Parameters for listing account changing history
     * @returns Promise<GetOptionsAccountChangeResp[]>
     */
    getOptionsAccountChange(params?: GetOptionsAccountChangeReq): Promise<OptionsAccountChangeRecord[]>;
    /**
     * List user's positions of specified underlying
     *
     * @param params Parameters for listing user's positions of specified underlying
     * @returns Promise<GetOptionsPositionsUnderlyingResp[]>
     */
    getOptionsPositionsUnderlying(params: {
        underlying?: string;
    }): Promise<OptionsPositionsUnderlying[]>;
    /**
     * Get specified contract position
     *
     * @param params Parameters for retrieving specified contract position
     * @returns Promise<GetOptionsPositionsUnderlyingResp>
     */
    getOptionsPositionContract(params: {
        contract: string;
    }): Promise<OptionsPositionsUnderlying>;
    /**
     * List user's liquidation history of specified underlying
     *
     * @param params Parameters for listing user's liquidation history of specified underlying
     * @returns Promise<GetOptionsLiquidationResp[]>
     */
    getOptionsLiquidation(params: {
        underlying: string;
        contract?: string;
    }): Promise<GetOptionsLiquidationResp[]>;
    /**
     * Create an options order
     *
     * @param params Parameters for creating an options order
     * @returns Promise<SubmitOptionsOrderResp>
     */
    submitOptionsOrder(params: SubmitOptionsOrderReq): Promise<SubmitOptionsOrderResp>;
    /**
     * List options orders
     *
     * @param params Parameters for listing options orders
     * @returns Promise<SubmitOptionsOrderResp[]>
     */
    getOptionsOrders(params: GetOptionsOrdersReq): Promise<SubmitOptionsOrderResp[]>;
    /**
     * Cancel all open orders matched
     *
     * @param params Parameters for canceling all open orders matched
     * @returns Promise<SubmitOptionsOrderResp[]>
     */
    cancelAllOpenOptionsOrders(params: {
        contract?: string;
        underlying?: string;
        side?: 'ask' | 'bid';
    }): Promise<SubmitOptionsOrderResp[]>;
    /**
     * Get a single order
     *
     * @param params Parameters for retrieving a single order
     * @returns Promise<SubmitOptionsOrderResp>
     */
    getOptionsOrder(params: {
        order_id: number;
    }): Promise<SubmitOptionsOrderResp>;
    /**
     * Cancel a single order
     *
     * @param params Parameters for canceling a single order
     * @returns Promise<SubmitOptionsOrderResp>
     */
    cancelOptionsOrder(params: {
        order_id: number;
    }): Promise<SubmitOptionsOrderResp>;
    /**
     * Countdown cancel orders for options
     *
     * Option order heartbeat detection. When the timeout set by the user is reached,
     * if there is no cancel or new countdown set, related pending orders will be
     * automatically cancelled. This endpoint can be called repeatedly to set a new
     * countdown or cancel the countdown.
     *
     * @param params Parameters for setting countdown cancel orders
     * @returns Promise<{
     *   triggerTime: number;
     * }>
     */
    submitOptionsCountdownCancel(params: {
        timeout: number;
        contract?: string;
        underlying?: string;
    }): Promise<{
        triggerTime: number;
    }>;
    /**
     * List personal trading history
     *
     * @param params Parameters for listing personal trading history
     * @returns Promise<GetOptionsPersonalHistoryResp[]>
     */
    getOptionsPersonalHistory(params: GetOptionsPersonalHistoryReq): Promise<OptionsUserHistoryRecord[]>;
    /**
     * Set MMP (Market Maker Protection) settings
     *
     * @param params Parameters for setting MMP settings
     * @returns Promise<OptionsMMPSetings>
     */
    setOptionsMMPSettings(params: OptionsMMPSettingsReq): Promise<OptionsMMPSettings>;
    /**
     * Query MMP (Market Maker Protection) settings
     *
     * @param params Parameters for querying MMP settings
     * @returns Promise<OptionsMMPSetings[]>
     */
    getOptionsMMPSettings(params?: {
        underlying?: string;
    }): Promise<OptionsMMPSettings[]>;
    /**
     * Reset MMP (Market Maker Protection) settings
     *
     * @param params Parameters for resetting MMP settings
     * @returns Promise<OptionsMMPSettings>
     */
    resetOptionsMMPSettings(params: {
        underlying: string;
    }): Promise<OptionsMMPSettings>;
    /**==========================================================================================================================
     * EARN UNI
     * ==========================================================================================================================
     */
    /**
     * List currencies for lending
     *
     * @returns Promise<GetLendingCurrenciesResp[]>
     */
    getLendingCurrencies(): Promise<LendingCurrency[]>;
    /**
     * Get currency detail for lending
     *
     * @param params Parameters for retrieving currency detail for lending
     * @returns Promise<GetLendingCurrenciesResp>
     */
    getLendingCurrency(params: {
        currency: string;
    }): Promise<LendingCurrency>;
    /**
     * Lend or redeem
     *
     * @param params Parameters for lending or redeeming
     * @returns Promise<any>
     */
    submitLendOrRedeemOrder(params: SubmitLendOrRedeemReq): Promise<any>;
    /**
     * List user's lending orders
     *
     * @param params Parameters for listing user's lending orders
     * @returns Promise<GetLendingOrdersResp[]>
     */
    getLendingOrders(params?: GetLendingOrdersReq): Promise<LendingOrder[]>;
    /**
     * Amend lending order
     *
     * Currently only supports amending the minimum interest rate (hour)
     *
     * @param params Parameters for amending lending order
     * @returns Promise<any>
     */
    updateLendingOrder(params: {
        currency?: string;
        min_rate?: string;
    }): Promise<any>;
    /**
     * List records of lending
     *
     * @param params Parameters for listing records of lending
     * @returns Promise<GetLendingRecordsResp[]>
     */
    getLendingRecords(params?: GetLendingRecordsReq): Promise<LendingRecord[]>;
    /**
     * Get the user's total interest income of specified currency
     *
     * @param params Parameters for retrieving the user's total interest income of specified currency
     * @returns Promise<{
     *   currency: string;
     *   interest: string;
     * }>
     */
    getLendingTotalInterest(params: {
        currency: string;
    }): Promise<{
        currency: string;
        interest: string;
    }>;
    /**
     * List interest records
     *
     * @param params Parameters for listing interest records
     * @returns Promise<GetLendingInterestRecordsResp[]>
     */
    getLendingInterestRecords(params?: GetLendingInterestRecordsReq): Promise<LendingInterestRecord[]>;
    /**
     * Set interest reinvestment toggle
     *
     * @param params Parameters for setting interest reinvestment toggle
     * @returns Promise<any>
     */
    updateInterestReinvestment(params: {
        currency: string;
        status: boolean;
    }): Promise<any>;
    /**
     * Query currency interest compounding status
     *
     * @param params Parameters for querying currency interest compounding status
     * @returns Promise<{
     *   currency: string;
     *   interest_status: string;
     * }>
     */
    getLendingInterestStatus(params: {
        currency: string;
    }): Promise<{
        currency: string;
        interest_status: string;
    }>;
    /**==========================================================================================================================
     * COLLATERAL LOAN
     * ==========================================================================================================================
     */
    /**
     * Place order
     *
     * @param params Parameters for placing an order
     * @returns Promise<{ order_id: number }>
     */
    submitLoanOrder(params: SubmitLoanOrderReq): Promise<{
        order_id: number;
    }>;
    /**
     * List Orders
     *
     * @param params Parameters for listing orders
     * @returns Promise<GetLoanOrdersResp[]>
     */
    getLoanOrders(params?: GetLoanOrdersReq): Promise<LoanOrder[]>;
    /**
     * Get a single order
     *
     * @param params Parameters for retrieving a single order
     * @returns Promise<GetLoanOrdersResp>
     */
    getLoanOrder(params: {
        order_id: number;
    }): Promise<LoanOrder>;
    /**
     * Repayment
     *
     * @param params Parameters for repayment
     * @returns Promise<{
     *   repaid_principal: string;
     *   repaid_interest: string;
     * }>
     */
    submitLoanRepay(params: {
        order_id: number;
        repay_amount: string;
        repaid_all: boolean;
    }): Promise<{
        repaid_principal: string;
        repaid_interest: string;
    }>;
    /**
     * Repayment history
     *
     * @param params Parameters for retrieving repayment history
     * @returns Promise<GetLoanRepaymentHistoryResp[]>
     */
    getLoanRepaymentHistory(params: GetLoanRepaymentHistoryReq): Promise<LoanRepaymentHistoryRecord[]>;
    /**
     * Increase or redeem collateral
     *
     * @param params Parameters for increasing or redeeming collateral
     * @returns Promise<any>
     */
    updateLoanCollateral(params: UpdateLoanCollateralReq): Promise<any>;
    /**
     * Query collateral adjustment records
     *
     * @param params Parameters for querying collateral adjustment records
     * @returns Promise<GetLoanCollateralRecordsResp[]>
     */
    getLoanCollateralRecords(params?: GetLoanCollateralRecordsReq): Promise<LoanCollateralRecord[]>;
    /**
     * Query the total borrowing and collateral amount for the user
     *
     * @returns Promise<{
     *   borrow_amount: string;
     *   collateral_amount: string;
     * }>
     */
    getLoanTotalAmount(): Promise<{
        borrow_amount: string;
        collateral_amount: string;
    }>;
    /**
     * Query user's collateralization ratio
     *
     * @param params Parameters for querying user's collateralization ratio
     * @returns Promise<GetLoanCollateralizationRatioResp>
     */
    getLoanCollateralizationRatio(params: {
        collateral_currency: string;
        borrow_currency: string;
    }): Promise<LoanCollateralRatio>;
    /**
     * Query supported borrowing and collateral currencies
     *
     * @param params Parameters for querying supported borrowing and collateral currencies
     * @returns Promise<{
     *   loan_currency: string;
     *   collateral_currency: string[];
     * }[]>
     */
    getLoanSupportedCurrencies(params?: {
        loan_currency?: string;
    }): Promise<{
        loan_currency: string;
        collateral_currency: string[];
    }[]>;
    /**==========================================================================================================================
     * MULTI COLLATERAL LOAN
     * ==========================================================================================================================
     */
    /**
     * Create Multi-Collateral Order
     *
     * @param params Parameters for creating a multi-collateral order
     * @returns Promise<{ order_id: number }>
     */
    submitMultiLoanOrder(params: SubmitMultiLoanOrderReq): Promise<{
        order_id: number;
    }>;
    /**
     * List Multi-Collateral Orders
     *
     * @param params Parameters for listing multi-collateral orders
     * @returns Promise<GetMultiLoanOrdersResp[]>
     */
    getMultiLoanOrders(params?: GetMultiLoanOrdersReq): Promise<MultiLoanOrder[]>;
    /**
     * Get Multi-Collateral Order Detail
     *
     * @param params Parameters for retrieving a multi-collateral order detail
     * @returns Promise<GetMultiLoanOrdersResp>
     */
    getMultiLoanOrder(params: {
        order_id: string;
    }): Promise<MultiLoanOrder>;
    /**
     * Repay Multi-Collateral Loan
     *
     * @param params Parameters for repaying a multi-collateral loan
     * @returns Promise<RepayMultiLoanResp>
     */
    repayMultiLoan(params: RepayMultiLoanReq): Promise<RepayMultiLoanResp>;
    /**
     * List Multi-Collateral Repay Records
     *
     * @param params Parameters for listing multi-collateral repay records
     * @returns Promise<GetMultiLoanRepayRecordsResp[]>
     */
    getMultiLoanRepayRecords(params: GetMultiLoanRepayRecordsReq): Promise<MultiLoanRepayRecord[]>;
    /**
     * Operate Multi-Collateral
     *
     * @param params Parameters for operating multi-collateral
     * @returns Promise<UpdateMultiLoanResp>
     */
    updateMultiLoan(params: UpdateMultiLoanReq): Promise<UpdateMultiLoanResp>;
    /**
     * Query collateral adjustment records
     *
     * @param params Parameters for querying collateral adjustment records
     * @returns Promise<GetMultiLoanAdjustmentRecordsResp[]>
     */
    getMultiLoanAdjustmentRecords(params?: GetMultiLoanAdjustmentRecordsReq): Promise<MultiLoanAdjustmentRecord[]>;
    /**
     * List User Currency Quota
     *
     * @param params Parameters for listing user currency quota
     * @returns Promise<GetMultiLoanCurrencyQuotaResp[]>
     */
    getMultiLoanCurrencyQuota(params: {
        type: 'collateral' | 'borrow';
        currency: string;
    }): Promise<MultiLoanCurrencyQuota[]>;
    /**
     * Query supported borrowing and collateral currencies in Multi-Collateral
     *
     * @returns Promise<GetMultiLoanSupportedCurrenciesResp>
     */
    getMultiLoanSupportedCurrencies(): Promise<MultiLoanSupportedCurrencies>;
    /**
     * Get Multi-Collateral ratio
     *
     * @returns Promise<GetMultiLoanRatioResp>
     */
    getMultiLoanRatio(): Promise<MultiLoanRatio>;
    /**
     * Query fixed interest rates for the currency for 7 days and 30 days
     *
     * @returns Promise<GetMultiLoanFixedRatesResp[]>
     */
    getMultiLoanFixedRates(): Promise<MultiLoanFixedRate[]>;
    /**
     * Query the current interest rate of currencies
     *
     * Query the current interest rate of currencies in the last hour.
     * The current interest rate is updated every hour.
     *
     * @param params Parameters containing currencies to query and optional VIP level
     * @returns Promise<MultiLoanCurrentRate[]>
     */
    getMultiLoanCurrentRates(params: {
        currencies: string[];
        vip_level?: string;
    }): Promise<{
        currency: string;
        current_rate: string;
    }[]>;
    /**==========================================================================================================================
     * EARN
     * ==========================================================================================================================
     */
    /**
     * ETH2 swap
     *
     * @param params Parameters for ETH2 swap
     * @returns Promise<any>
     */
    submitEth2Swap(params: {
        side: '1' | '2';
        amount: string;
    }): Promise<any>;
    /**
     * Dual Investment product list
     *
     * @returns Promise<GetDualInvestmentProductsResp[]>
     */
    getDualInvestmentProducts(): Promise<DualInvestmentProduct[]>;
    /**
     * Dual Investment order list
     *
     * @returns Promise<GetDualInvestmentOrdersResp[]>
     */
    getDualInvestmentOrders(): Promise<DualInvestmentOrder[]>;
    /**
     * Place Dual Investment order
     *
     * @param params Parameters for placing a dual investment order
     * @returns Promise<any>
     */
    submitDualInvestmentOrder(params: {
        plan_id: string;
        copies: string;
        is_max: number;
        amount: string;
    }): Promise<any>;
    /**
     * Structured Product List
     *
     * @param params Parameters for listing structured products
     * @returns Promise<GetStructuredProductListResp[]>
     */
    getStructuredProducts(params: GetStructuredProductListReq): Promise<StructuredProduct[]>;
    /**
     * Structured Product Order List
     *
     * @param params Parameters for listing structured product orders
     * @returns Promise<GetStructuredProductOrdersResp[]>
     */
    getStructuredProductOrders(params?: GetStructuredProductOrdersReq): Promise<StructuredProductOrder[]>;
    /**
     * Place Structured Product Order
     *
     * @param params Parameters for placing a structured product order
     * @returns Promise<any>
     */
    submitStructuredProductOrder(params: {
        pid?: string;
        amount?: string;
    }): Promise<any>;
    /**==========================================================================================================================
     * ACCOUNT
     * ==========================================================================================================================
     */
    /**
     * Get account detail
     *
     * @returns Promise<GetAccountDetailResp>
     */
    getAccountDetail(): Promise<AccountDetail>;
    /**
     * Get user transaction rate limit information
     *
     * @returns Promise<AccountRateLimit[]>
     */
    getAccountRateLimit(): Promise<AccountRateLimit[]>;
    /**
     * Create STP Group
     *
     * @param params Parameters for creating an STP group
     * @returns Promise<CreateStpGroupResp>
     */
    createStpGroup(params: CreateStpGroupReq): Promise<StpGroup>;
    /**
     * List STP Groups
     *
     * @param params Parameters for listing STP groups
     * @returns Promise<CreateStpGroupResp[]>
     */
    getStpGroups(params?: {
        name?: string;
    }): Promise<StpGroup[]>;
    /**
     * List users of the STP group
     *
     * @param params Parameters for listing users of the STP group
     * @returns Promise<StpResp[]>
     */
    getStpGroupUsers(params: {
        stp_id: number;
    }): Promise<StpGroupUser[]>;
    /**
     * Add users to the STP group
     *
     * @param params Parameters for adding users to the STP group
     * @returns Promise<StpResp[]>
     */
    addUsersToStpGroup(params: {
        stp_id: number;
        body: number[];
    }): Promise<StpGroupUser[]>;
    /**
     * Delete the user in the STP group
     *
     * @param params Parameters for deleting users from the STP group
     * @returns Promise<StpResp[]>
     */
    deleteUserFromStpGroup(params: {
        stp_id: number;
        user_id: number;
    }): Promise<StpGroupUser[]>;
    /**
     * Set GT deduction
     *
     * Enable or disable GT deduction for the current account.
     *
     * @param params Parameters for setting GT deduction
     * @returns Promise<void>
     */
    setGTDeduction(params: {
        enabled: boolean;
    }): Promise<void>;
    /**
     * Query GT deduction configuration
     *
     * Query the current GT deduction configuration for the account.
     *
     * @returns Promise<{ enabled: boolean }>
     */
    getGTDeduction(): Promise<{
        enabled: boolean;
    }>;
    /**==========================================================================================================================
     * REBATES
     * ==========================================================================================================================
     */
    /**
     * The agency obtains the transaction history of the recommended user.
     * Record time range cannot exceed 30 days.
     *
     * @param params Parameters for retrieving transaction history
     * @returns Promise<GetAgencyTransactionHistoryResp>
     */
    getAgencyTransactionHistory(params: GetAgencyTransactionHistoryReq): Promise<{
        total: number;
        list: AgencyTransactionHistoryRecord[];
    }>;
    /**
     * The agency obtains the commission history of the recommended user.
     * Record time range cannot exceed 30 days.
     *
     * @param params Parameters for retrieving commission history
     * @returns Promise<GetAgencyCommissionHistoryResp>
     */
    getAgencyCommissionHistory(params: GetAgencyCommissionHistoryReq): Promise<{
        total: number;
        list: AgencyCommissionHistoryRecord[];
    }>;
    /**
     * Partner obtains transaction records of recommended users
     *
     * Record time range cannot exceed 30 days.
     *
     * @param params Parameters for retrieving transaction records
     * @returns Promise<GetPartnerTransactionHistoryResp>
     */
    getPartnerTransactionHistory(params?: PartnerTransactionReq): Promise<{
        total: number;
        list: PartnerTransaction[];
    }>;
    /**
     * Partner obtains commission records of recommended users
     *
     * Record time range cannot exceed 30 days.
     *
     * @param params Parameters for retrieving commission records
     * @returns Promise<GetPartnerCommissionHistoryResp>
     */
    getPartnerCommissionHistory(params?: PartnerTransactionReq): Promise<{
        total: number;
        list: PartnerCommission[];
    }>;
    /**
     * Partner subordinate list
     *
     * Including sub-agents, direct customers, indirect customers
     *
     * @param params Parameters for retrieving partner subordinate list
     * @returns Promise<{
     *   total: number;
     *   list: {
     *     user_id: number;
     *     user_join_time: number;
     *     type: number;
     *     desc: string;
     *   }[];
     * }>
     */
    getPartnerSubordinateList(params?: GetPartnerSubordinateListReq): Promise<{
        total: number;
        list: PartnerSubordinate[];
    }>;
    /**
     * The broker obtains the user's commission rebate records.
     * Record time range cannot exceed 30 days.
     *
     * @param params Parameters for retrieving commission rebate records
     * @returns Promise<GetBrokerCommissionHistoryResp>
     */
    getBrokerCommissionHistory(params: GetBrokerCommissionHistoryReq): Promise<{
        total: number;
        list: BrokerCommissionHistoryRecord[];
    }>;
    /**
     * The broker obtains the user's trading history.
     * Record time range cannot exceed 30 days.
     *
     * @param params Parameters for retrieving trading history
     * @returns Promise<GetBrokerTransactionHistoryResp>
     */
    getBrokerTransactionHistory(params: GetBrokerTransactionHistoryReq): Promise<{
        total: number;
        list: BrokerTransactionHistoryRecord[];
    }>;
    /**
     * User retrieves rebate information.
     */
    getUserRebateInfo(): Promise<{
        invite_uid: number;
    }>;
    /**
     * Query user-subordinate relationship
     *
     * Checks whether specified users are in the system and their relationship status
     */
    getUserSubordinateRelationships(params: {
        user_id_list: string;
    }): Promise<{
        list: {
            uid: number;
            belong: string;
            type: number;
            ref_uid: number;
        }[];
    }>;
}
